/* Copyright (c) 2015 Asustor Inc. All rights reserved. */


Ext.ns('AS.ARC.syslogServer');

/**
 * @class AS.ARC.apps.syslogSer sidebar button
 * @extends Ext.button.Button
 *<p></p>
 */

Ext.define('AS.ARC.apps.syslogServer.core.sideButton', {
	extend: 'Ext.button.Button',

	alias: ['widget.asSysSideBtn'],

	normalIcon: '',
	overIcon: '',

	initComponent: function () {
		var me = this;

		me.callParent(arguments);

		me.on('mouseover', me.handlemouseover);

		me.on('mouseout', me.handlemouseout);

		me.on('toggle', me.handletoggle);
	},

	beforeDestroy: function () {
		var me = this;

		me.un('mouseover', me.handlemouseover);

		me.un('mouseout', me.handlemouseout);

		me.un('toggle', me.handletoggle);

		me.callParent(arguments);
	},

	handlemouseover: function () {
		var me = this;
		
		if (me.pressed) {
			me.el.setStyle('background','#6BCBEE');
		} else {
			me.el.setStyle('background', '#D3D6E1');	
		}
	},

	handlemouseout: function () {
		var me = this;
		
		if (me.pressed) {
			me.el.setStyle('background','#6BCBEE');
		} else {
			me.el.setStyle('background', '#EAEBEE');	
		}
	},

	handletoggle: function () {
		var me = this;

		if (me.pressed) {
			me.el.setStyle('background','#6BCBEE');
		} else {
			me.el.setStyle('background', '#EAEBEE');	
		}
		
	}


});

/**
 * @class AS.ARC.apps.syslogServer FolderSelector
 * @extends Ext.container.Container
 * <p></p> 
 */
Ext.define('AS.ARC.apps.syslogServer.FolderSelector', {
	extend: 'AS.ARC.subWindow',
	
	apiUrl: null,
	
	title: _S('COMMON', 'BROWSE'),
	
	parentWin: null,
	
	pathCmp: null,
	
	width: 500,
	
	height: 400,
	
	layout: 'fit',
	
	initComponent: function () {
		var me = this;
		
		me.apiUrl = me.apiUrl || AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer');
		
		me.addEvents({
			exception: true,
			selectionchange: true
		});
		
		me.buttonApply = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'OK'),
			disabled: true,
			handler: function () {
				var path = me.getValue();
				
				if (path && me.pathCmp) {
					me.pathCmp.setValue(path.substring(1));
				}
				
				me.close();
			},
			scope: me
		});
		
		me.buttonCancel = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'CANCEL'),
			handler: function () {
				me.close();
			}
		});
		
		var treeStore = Ext.create('Ext.data.TreeStore', {
			autoLoad: false,
			autoDestroy: true,
			fields: [
				{name: 'file_path'}, 
				{name: 'id', mapping: 'file_path'}, 
				{name: 'filename'}, 
				{name: 'path', mapping: 'physical_path'}
			],
			defaultRootId: '',
			nodeParam: 'path',
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(me.apiUrl, {act: 'file_list'}),
				method: 'post',
				extraParams: {
					onlydir: true,
					showhome: true
				},
				actionMethods: {
					create: 'POST', 
					read: 'POST', 
					update: 'POST', 
					destroy: 'POST'
				},
				reader: {
					type: 'json',
					root: 'data'
				},
				listeners: {
					exception: function (proxy, response, operation, opts) {
						me.fireEvent('exception', proxy, response, operation, opts);
					}
				}
			}
		});
		
		me.tree = Ext.create('Ext.tree.TreePanel', {
			rootVisible: false,
			useArrows : true,
			autoScroll: true,
			border: false,
			resizable: false,
			store: treeStore,
			displayField: 'filename',
			animate: false,
			// tbar: [{
				// text: _S('COMMON', 'CREATE_FOLDER')
			// }],
			getSelection: function () {
				return this.getSelectionModel().getSelection();
			},
			
			listeners: {
				selectionchange: function (sm, selections) {
					me.fireEvent('selectionchange', sm, selections);
					
					if (selections.length > 0) {
						me.buttonApply.enable();
					} else {
						me.buttonApply.disable();
					}
				}
			}
		});
		
		Ext.apply(me, {
			items: [{
				xtype: 'asPanelTop10',
				layout: 'fit',
				items: me.tree
			}],
			fbar: [
				me.buttonApply,
				me.buttonCancel,
			]
		});
		
		me.callParent();
	},
	
	getValue: function () {
		var me = this;
		
		var selections = me.tree.getSelection();
			
		if (selections.length > 0) {
			return selections[0].data.path;
		}
		
		return null;
	}
});

/**
 * File selector
 */
Ext.define('AS.ARC.apps.syslogServer.fileSelector', {
	extend: 'Object',
	
	path: [],
	fullPath: '',
	phyPath: [],
	fullPhyPath: '',
	// For select iso file
	isoOnly: false,
	backName: '',
	
	disableMyArchive: false,

	constructor: function (config) {
		Ext.apply(this, config);
		this.callParent();
		
		this.init();		
		this.createWindow();
	},
	
	init: function () {
		this.path = [];
		this.fullPath = '';
		
		this.phyPath = [];
		this.fullPhyPath = '';
	},
	
	getGridFileStore: function (path) {
		var fs = this;
		
		var urlOpts = {
			act: 'get_list',
			path: path,
			sort: 'name',
			dir: 'asc'
		};
		
		return Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				'text',
				'filesize',
				'type'
			],
			pageSize: 1000,
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer'), urlOpts),
				reader: {
					type: 'json',
					root: 'datas'
				}
			},
			listeners: {
				load : function (ds, o, a) {
					if(fs.backName != '') {
						var index = 0;
						ds.each(function(element) {
							if(element.data.text == fs.backName) {
								return false;
							}
							index++;
						});
						
						fs.backName = '';
						
						if (index < ds.getCount()) {
							if (fs.path.length < 1) {
								fs.gridTree.selModel.select(index);
							}else{
								setTimeout(function(){
									fs.gridFile.selModel.select(index);
								},10);
							}
						}
					}
				}
			}
		});
	},
	
	getFullPath: function () {
		return '/' + this.path.join('/');
	},
	
	getFullPhyPath: function() {
		//return '/' + this.phyPath.join('/');
		
		var fullPhyPath = '';
		
		for(var i = 0; i < this.phyPath.length; i ++) {
			fullPhyPath = fullPhyPath + this.phyPath[i] + '/';
		}
		
		return fullPhyPath;
		//return '/' + this.phyPath.join('/');
	},
	
	loadGridFile: function (path) {
		var fs = this;
		
		fs.storeFile = fs.getGridFileStore(path);
		fs.gridFile.reconfigure(fs.storeFile);
		fs.storeFile.load();
		
	},
	
	checkNavi: function () {
		var fs = this;
		
		// Disable button Ok
		fs.buttonOk.disable();
		
		if (fs.path.length > 0) {
			fs.buttonBack.enable(true);
			fs.mainGrids.layout.setActiveItem(1);
			
			// Update locatoin bar
			fs.locatoinBar.setValue(fs.getFullPath() );
		} else {
			fs.buttonBack.enable(false);
			fs.mainGrids.layout.setActiveItem(0);
			
			// Update locatoin bar
			fs.locatoinBar.setValue('/');
		}
	},
	//define media type
	MEDIA_TYPE_3G2: '3g2',
	MEDIA_TYPE_3GP: '3gp',
	MEDIA_TYPE_ASF: 'asf',
	MEDIA_TYPE_ASX: 'asx',
	MEDIA_TYPE_AVI: 'avi',
	MEDIA_TYPE_FLV: 'flv',
	MEDIA_TYPE_M3U: 'm3u',
	MEDIA_TYPE_M4A: 'm4a',
	MEDIA_TYPE_MKV: 'mkv',
	MEDIA_TYPE_MOV: 'mov',
	MEDIA_TYPE_MP3: 'mp3',
	MEDIA_TYPE_MP4: 'mp4',
	MEDIA_TYPE_MPA: 'mpa',
	MEDIA_TYPE_MPEG: 'mpeg',
	MEDIA_TYPE_MPG: 'mpg',
	MEDIA_TYPE_REC: 'rec',
	MEDIA_TYPE_RM: 'rm',
	MEDIA_TYPE_RMVB: 'rmvb',
	MEDIA_TYPE_VOB: 'vob',
	MEDIA_TYPE_WMV: 'wmv',
	MEDIA_TYPE_WSF: 'wsf',
	//define img type
	IMG_TYPE_JPG: 'jpg',
	IMG_TYPE_PNG: 'png',
	IMG_TYPE_GIF: 'gif',
	IMG_TYPE_BMP: 'bmp',
	IMG_TYPE_EPS: 'eps',
	IMG_TYPE_JPEG: 'jpeg',
	IMG_TYPE_TIF: 'tif',
	//define office type	
	OFFICE_TYPE_TXT: 'txt',
	OFFICE_TYPE_EXCEL: 'excel',
	OFFICE_TYPE_HTML: 'html',
	OFFICE_TYPE_PDF: 'pdf',
	OFFICE_TYPE_POWERPOINT: 'power-point',
	OFFICE_TYPE_WORD: 'word',
	OFFICE_TYPE_XML: 'xml',
	OFFICE_TYPE_DOC: 'doc',
	OFFICE_TYPE_DOCX: 'docx',
	OFFICE_TYPE_XLSX: 'xlsx',
	OFFICE_TYPE_XLS: 'xls',
	OFFICE_TYPE_PPTX: 'pptx',
	OFFICE_TYPE_PPT: 'ppt',
	//define compress type
	COMPRESS_TYPE_7Z: '7z',
	COMPRESS_TYPE_ZIP: 'zip',
	COMPRESS_TYPE_RAR: 'rar',
	COMPRESS_TYPE_GZ: 'gz',
	//define mount type
	MOUNT_TYPE_EXE: 'exe',
	MOUNT_TYPE_ISO:'iso',
	createWindow: function () {
		var fs = this;
		var typearray = [ 
			fs.MEDIA_TYPE_3G2 , 
			fs.MEDIA_TYPE_3GP, 
			fs.MEDIA_TYPE_ASF,
			fs.MEDIA_TYPE_ASX,
			fs.MEDIA_TYPE_AVI,
			fs.MEDIA_TYPE_FLV,
			fs.MEDIA_TYPE_M3U,
			fs.MEDIA_TYPE_M4A,
			fs.MEDIA_TYPE_MKV,
			fs.MEDIA_TYPE_MOV,
			fs.MEDIA_TYPE_MP3,
			fs.MEDIA_TYPE_MP4,
			fs.MEDIA_TYPE_MPA,
			fs.MEDIA_TYPE_MPEG,
			fs.MEDIA_TYPE_MPG,
			fs.MEDIA_TYPE_REC,
			fs.MEDIA_TYPE_RM,
			fs.MEDIA_TYPE_RMVB,
			fs.MEDIA_TYPE_VOB,
			fs.MEDIA_TYPE_WMV,
			fs.MEDIA_TYPE_WSF,
			fs.IMG_TYPE_JPG,
			fs.IMG_TYPE_PNG,
			fs.IMG_TYPE_GIF,
			fs.IMG_TYPE_BMP,
			fs.IMG_TYPE_EPS,
			fs.IMG_TYPE_JPEG,
			fs.IMG_TYPE_TIF,
			fs.OFFICE_TYPE_DOC,
			fs.OFFICE_TYPE_DOCX,
			fs.OFFICE_TYPE_TXT,
			fs.OFFICE_TYPE_EXCEL,
			fs.OFFICE_TYPE_XLSX,
			fs.OFFICE_TYPE_XLS,
			fs.OFFICE_TYPE_HTML,
			fs.OFFICE_TYPE_PDF,
			fs.OFFICE_TYPE_POWERPOINT,
			fs.OFFICE_TYPE_PPTX,
			fs.OFFICE_TYPE_PPT,
			fs.OFFICE_TYPE_WORD,
			fs.OFFICE_TYPE_XML,
			fs.COMPRESS_TYPE_7Z,
			fs.COMPRESS_TYPE_ZIP,
			fs.COMPRESS_TYPE_RAR,
			fs.COMPRESS_TYPE_GZ,
			fs.COMPRESS_TYPE_TAR,
			fs.COMPRESS_TYPE_WIM,
			fs.COMPRESS_TYPE_GZIP,
			fs.MOUNT_TYPE_ISO,
			fs.MOUNT_TYPE_EXE
			
		];
		var typeUrl = [ 
			'3G2.png',
			'3gp.png',
			'asf.png',
			'asx.png',
			'avi.png',
			'flv.png',
			'm3u.png',
			'm4a.png',
			'mkv.png',
			'mov.png',
			'mp3.png',
			'mp4.png',
			'mpa.png',
			'mpeg.png',
			'mpg.png',
			'rec.png',
			'rm.png',
			'rmvb.png',
			'vob.png',
			'wmv.png',
			'wsf.png',
			'jpg.png',
			'png.png',
			'gif.png',
			'bmp.png',
			'eps.png',
			'jpeg.png',
			'tif.png',
			'word.png',
			'word.png',
			'txt.png',
			'excel.png',
			'excel.png',
			'excel.png',
			'html.png',
			'pdf.png',
			'power-point.png',
			'power-point.png',
			'power-point.png',
			'word.png',
			'xml.png',
			'7z.png',
			'zip.png',
			'rar.png',
			'gz.png',
			'tar.png',
			'wim.png',
			'gzip.png',
			'iso.png',
			'exe.png'
			
		];
		fs.storeTree = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'text', mapping: 'filename'},
				{name: 'id', mapping: 'file_path'},
				{name: 'phy_path', mapping: 'physical_path'}
			],
			pageSize: 1000,
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getApiUrl('fileExplorer.cgi', 'fileExplorer'), {act:'file_list'}),
				reader: {
					type: 'json',
					root: 'data'
				},
				extraParams: {
					showhome: true
				}
			},
			listeners: {
				load: function (ds, o, a) {
					if (fs.disableMyArchive) {
						var myarchive1 = '/volume1/MyArchive1',
							myarchive2 = '/volume1/MyArchive2';
						ds.filter([{
							filterFn: function (item) {								
								if (item.get('phy_path') === myarchive1 ||
									item.get('phy_path') === myarchive2) {
									return false;
								} else {
									return true;
								}
						}
						}]);
					}

					if(fs.backName != '') {
						var index = 0;
						ds.each(function(element) {
							if(element.data.text == fs.backName) {
								return false;
							}
							index++;
						});
						fs.backName = '';
						if (index < ds.getCount()) {
							if (fs.path.length < 1) {
								fs.gridTree.selModel.select(index);
							}else{
								setTimeout(function(){
									fs.gridFile.selModel.select(index);
								},10);
							}
						}
					}
				}
			}
		});
		
		fs.gridTree = Ext.create('Ext.grid.GridPanel', {
			itemId: 'grid-tree',
			height: 250,
			width: '100%',
			border: 0,
			columns: [{
				text: _S('COMMON', 'NAME'),
				sortable: false,
				dataIndex: 'text',
				flex: 1,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					var result = '';			
					var name = value;	
					result = '<img src="apps/fileExplorer/images/files_list/folder_close.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
					
					return result;
				}
			}],
			store: fs.storeTree,
			listeners: {
				render: function () {
					fs.storeTree.load();
				},
				itemdblclick: function (view, record, item, index, e, eOpts) {
					//_D('itemdblclick');
					// Add to path
					fs.path.push(record.get('text') );
					
					if (fs.phyPath.length < 1) {
						fs.phyPath.push(record.get('phy_path'));
					} else {
						fs.phyPath.push(record.get('text'));
					}
					
					// Go to file grid
					fs.mainGrids.layout.setActiveItem(1);
					
					// Load grid
					fs.loadGridFile(record.get('id') );
					
					// Check navi bar
					fs.checkNavi();
				},
				scope: fs
			}
		});
		
		fs.storeFile = fs.getGridFileStore('/');
		fs.backRecord = '';
		fs.gridFile = Ext.create('Ext.grid.GridPanel', {
			itemId: 'grid-file',
			height: 240,
			width: 455,
			border: 0,
			columns: [{
				text: _S('COMMON', 'NAME'),
				sortable: false,
				dataIndex: 'text',
				flex: 1,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					var result = '',
						value = value.replace(/\u0020/ig, '&nbsp;'),
						name = value;
					//_D('record.data.type.toLowerCase():'+record.data.type.toLowerCase());
					if (record.data.type.toLowerCase() == 'dir') {
						result = '<img src="apps/fileExplorer/images/files_list/folder_close.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
						
					} else {
						var length = typearray.length;						
						for(var i=0; i < length; i++) {
							if(record.data.type.toLowerCase() == typearray[i]){
								result = '<img src="apps/fileExplorer/images/files_list/'+typeUrl[i] + '" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
								break;
							}else{
								result = '<img src="apps/fileExplorer/images/files_list/unknow.png" style="width:20px; height:20px; float: left; margin-top:-4px; margin-left:2px;" >&nbsp;<span style="margin-top: -4px;">&nbsp; '+ name+'</span>';
							}
						}
						
					}
					cell.tdAttr = 'data-qtip="' + value + '"';
					return result;
				}
			}, {
				text: _S('COMMON', 'SIZE'),
				sortable: false,
				dataIndex: 'filesize',
				width: 100,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					if (record.get('type') === 'dir') {
						return '';
					} else {
						return AS.ARC.util.convertSizeUnit(value);
					}
				}
			}, {
				text: _S('COMMON', 'TYPE'),
				sortable: false,
				dataIndex: 'type',
				width: 100,
				draggable: false,
				renderer: function (value, cell, record, rowIndex, columnIndex, store) {
					return value;
				}
			}],
			store: fs.storeFile,
			listeners: {
				render: function () {
					//fs.storeFile.load();
				},
				itemclick : function (view, record, item, index, e, eOpts) {
					var okEnable = false;
					
					// if select directory
					if (record.get('type') !== 'dir') {
						// if select iso file
						if (fs.isoOnly) {
							if (/.\.db/.test(record.get('text').toLowerCase() ) ) {
								
								okEnable = true;
							}
						} else {
							okEnable = true;
						}
					}
					
					if (okEnable) {
						fs.buttonOk.enable();
					} else {
						fs.buttonOk.disable();
					}
				},
				itemdblclick: function (view, record, item, index, e, eOpts) {
					_D('itemdblclick - ' + record.get('text'));
					fs.backRecord = record;
					_D('back index - ' + fs.backRecord.get('text'));
					if (record.get('type') === 'dir') {
						// Add to path
						fs.path.push(record.get('text') );
						
						if (fs.phyPath.length < 1) {
							fs.phyPath.push(record.get('phy_path'));
						} else {
							fs.phyPath.push(record.get('text'));
						}
						
						fs.storeFile = fs.getGridFileStore(fs.getFullPath() );
						fs.gridFile.reconfigure(fs.storeFile);
						fs.storeFile.load();
						
						// Check navi bar
						fs.checkNavi();
					} else if (fs.isoOnly) {
						if (/.\.db/.test(record.get('text').toLowerCase() ) ) {
							// return selected path
							fs.fullPath = fs.getFullPath() + '/' + record.get('text');
							fs.fullPhyPath = fs.getFullPhyPath() + record.get('text');
							
							
							fs.handleOk(fs.parentOpts);
							fs.win.close();
						}
					} else {
						// return selected path
						fs.fullPath = fs.getFullPath() + '/' + record.get('text');
						fs.fullPhyPath = fs.getFullPhyPath() + record.get('text');
						
						
						fs.handleOk(fs.parentOpts);
						fs.win.close();
					}
				},
				scope: fs
			}
		});
		
		fs.mainGrids = Ext.create('Ext.panel.Panel', {
			region: 'center',
			itemId: 'main-grids',
			height: 250,
			border: 0,
			layout: 'card',
			activeItem: 0,
			items: [
				fs.gridTree,
				fs.gridFile
			]		
		});
		
		fs.buttonBack = Ext.create('Ext.Img', {
			width: 39,
			height: 31,
			baseCls: "as-imgBtn-fileChooser",
			enabled: false,

			imgNormal: "resources/images/accessControl/browseBtn_normal.png",
			imgPress: "resources/images/accessControl/browseBtn_press.png",
			imgHover: "resources/images/accessControl/browseBtn_over.png",
			imgDisable: "resources/images/accessControl/browseBtn_normal.png",

			enable: function (enable){
				var btn = this;
				btn.enabled = enable;
				btn.onNormal();
			},

			iniEvent: function(){
				var btn = this;
				Ext.fly(this.el).on('click', function(e, t) {
					btn.onClick();
				});
				Ext.fly(this.el).on('mousedown', function(e, t) {
					btn.onPress();
				});
				Ext.fly(this.el).on('mouseup', function(e, t) {
					btn.onNormal();
				});
				Ext.fly(this.el).on('mouseover', function(e, t) {
					btn.onHover();
				});
				Ext.fly(this.el).on('mouseout', function(e, t) {
					btn.onNormal();
				});
			},

			onClick: function () {
				var btn = this;
				if (btn.enabled) {
					fs.backflag = true;
					fs.backName = fs.path.splice((fs.path.length - 1), 1);
					_D('back index - ' + fs.backRecord )
					// Check navi bar
					fs.checkNavi();
					if (fs.path.length < 1) {
						fs.storeTree.load();
					} else {
						
						fs.loadGridFile(fs.getFullPath() );

					}
				}
			},

			onPress: function(){
				var btn = this;

				var img = btn.imgPress;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			onHover: function(){
				var btn = this;

				var img = btn.imgHover;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			onNormal: function(){
				var btn = this;
				var img = btn.imgNormal;
				if( !btn.enabled ){
					img = btn.imgDisable;
				}// end if
				btn.setSrc(img);
			},

			listeners: {
				render: function( com, eOpts ) {
					var btn = this;
					btn.iniEvent();
					btn.enable( btn.enabled );
				}
			}
		});
		
		fs.buttonOk = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'OK'),
			scale: AS.ARC.config.defaultActionButtonSize,
			disabled: true,
			handler: function () {
				// return selected path
				var selections = fs.gridFile.getSelectionModel().getSelection();

				fs.fullPath = fs.getFullPath() + '/' + selections[0].data.text;
				fs.fullPhyPath = fs.getFullPhyPath()  + selections[0].data.text;
				
				fs.handleOk(fs.parentOpts);
				fs.win.close();
			},
			scope: fs
		});
		
		fs.buttonCancel = Ext.create('Ext.button.Button', {
			text: _S('COMMON', 'CANCEL'),
			scale: AS.ARC.config.defaultActionButtonSize,
			handler: function () {
				fs.win.close();
			},
			scope: fs
		});
		
		fs.locatoinBar = Ext.create('Ext.form.TextField', {
			width: 430,
			height: 24,
			margin: '2 0 0 0',
			value: '/'
		});
		
		fs.win = Ext.create('AS.ARC.subWindow', {
			parentWin: fs.parentWin,
			title: _S('COMMON', 'BROWSE'),
			width: 500,
			height: 400,
			fbar: [
				fs.buttonOk,
				fs.buttonCancel
			],
			items: [{
				xtype: 'asPanelTop10',
				itemId: 'main-panel',
				height: 300,
				items: [{
					xtype: 'container',
					height: 35,
					layout: 'hbox',
					items: [
						fs.buttonBack,
						{
							xtype: 'tbfill'
						},
						fs.locatoinBar
					]
				},
					fs.mainGrids
				]
			}]
		});
	}
});


/**
 * @class AS.ARC.apps.syslogServer search
 * @extends Ext.container.Container
 * <p></p> 
 */
Ext.define('AS.ARC.apps.syslogServer.core.search', {
	extend: 'Ext.container.Container',

	alias: ['widget.asSysSearch'],

	width: 183,
	layout: 'hbox',

	cloneStore: Ext.create(Ext.data.Store, {}),

	columnName: '',

	initComponent: function () {
		var me = this;

		me.items = [
			{
				xtype: 'textfield',
				itemId: 'text',
				height: 25,
				emptyText: 'Filter'
			}, {
				xtype: 'container',
				height: 25,
				width: 25,
				margin: '0 0 0 3',
			}
		];

		me.callParent(arguments);

		//var textfield = me.items.get('text');
		//textfield.columnName = me.columnName;
		//textfield.on('change', me.handle)
	}

});

/**
 * @class AS.ARC.apps.syslogServer.core
 * @extends Ext.util.Observable
 *<p>core</p>
 */

Ext.define('AS.ARC.apps.syslogServer.core', {
	extend: 'Ext.util.Observable',
	fn: this,
	apiUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi',
	imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
	
	activeItem: 0,
	toggleAfterConfirm: 0,
	
	uiChecker: {
		//server_settings
		enable_syslog_server: false,
		enable_tcp: false,
		tcp_port: 0,
		enable_ssl: false,
		enable_udp: false,
		udp_port: 0,
		
		//archive
		default_path: '',
		log_name: '',
		format: 0,
		enable_size: false,
		size_value: 0,
		enable_count: false,
		count_value: 0,
		enable_earlier: false,
		earlier_value: 0,
		
		//notification
		enable_limit: false,
		limit_value: 1,
		enable_severity: false,
		severity_value: 0,
		enable_keyword: false,
		keyword1: '',
		keyword2: '',
		keyword3: ''
		
	},

	constructor: function (config) {
		Ext.apply(this, config);
		//execute parent constructor
		this.callParent();
		//To initialize syslogServer
		this.init(config);
	},

	init: function () {
		var fn = this;

		//create an syslogServer app
		fn.win = fn.desktop.createWindow({
			app: fn.app,
			id: fn.id,
			itemId: fn.id,
			width: 880,
			height: 550,
			resizable: false,
			border: false,
			layout: 'fit',
			items: [
				fn.getMainPanel()
			],
			listeners: {
				afterrender: function (win) {
					win.header.items.items[1].hide();
					fn.loadData('serversettings');
					fn.loadData('archive');
					fn.loadData('notification');
				}
			}

		});

	},

	getMainPanel: function () {
		var fn = this;

		var sidebarPanel = Ext.create(Ext.panel.Panel, {
			itemId: 'sidebar',
			region: 'west',
			cls: 'syslogServer-side-btn',
			height: 550,
			width: 170,
			bodyStyle: 'padding:0px 0px 10px 0px;background-color:#EAEBEE; border-width: 0px; border-style: none; border-right: 1px solid #cdd0d7;',
			items: [
				{
					xtype: 'container',
					itemId: 'container',
					//height: 491,
					width: 170,
					defaults: {
						width: 175,
						height: 25,
						margin: -1
					},
					items: [
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn1',
								style: "background: #6BCBEE; border:none;",
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-overview.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								pressed: true,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'OVERVIEW'),
								toggleHandler: function (me, state) {
									if(!state) {
									//	clearTimeout(fn.listJobId);
										return;
									}
									
									clearInterval(fn.statisticsChartId);
									var contLayout = contentPanel.getLayout(),
										activeItem = contLayout.getActiveItem(),
										statisticsChart = contentPanel.items.get('tabpanel').items.get('statistics-tab').items.get('statisticschart'),
										deviceChart = contentPanel.items.get('tabpanel').items.get('device-tab').items.get('devicechart'),
										levelChart = contentPanel.items.get('tabpanel').items.get('level-tab').items.get('levelchart'),
										activeIndex = contentPanel.items.get('tabpanel').items.indexOf(contentPanel.items.get('tabpanel').getLayout().activeItem),
										statisticsChartCombo = contentPanel.items.get('tabpanel').items.get('statistics-tab').items.get('combobox');
									contLayout.setActiveItem(0);
									fn.activeItem = 0;
									
									
									
									if (activeIndex == 0) {
										statisticsChart.loadData({
											time: statisticsChartCombo.getValue()
										});
										fn.statisticsChartId = setInterval(function() {
											statisticsChart.loadData({

												time: statisticsChartCombo.getValue()

											});
										}, 20000);
									} else if(activeIndex == 1) {
										fn.loadPieChart(1, deviceChart);
									} else {
										fn.loadPieChart(2, levelChart);
									}
									
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}, 
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn2',
								style: 'background: #EAEBEE; border:none;',
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-log.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'LOG'),
								toggleHandler: function (me, state) {
									if(!state) return;
									contentPanel.getLayout().setActiveItem(1);
									fn.activeItem = 1;
									
									contentPanel.items.get('logPanel').items.get('logTab').items.get('grid').store.load({
										params: {
											tab: 'List'
										}
									});
									
									clearInterval(fn.statisticsChartId);
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}, 
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn3',
								style: 'background: #EAEBEE; border:none;',
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-serversetting.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'SERVER_SETTINGS'),
								toggleHandler: function (me, state) {
									if(!state) return;
									contentPanel.getLayout().setActiveItem(2);
									
									clearInterval(fn.statisticsChartId);
									
									fn.loadData('serversettings');
									fn.loadData('notification');
									fn.loadData('archive');
									sidebarPanel.items.get('container').items.get('sideBtn1').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn2').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn4').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn5').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn6').enableToggle = false;
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}, 
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn4',
								style: 'background: #EAEBEE; border:none;',
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-archive.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'ARCHIVE'),
								toggleHandler: function (me, state) {
									if(!state) return;

									contentPanel.getLayout().setActiveItem(3);
									clearInterval(fn.statisticsChartId);
									
									fn.loadData('serversettings');
									fn.loadData('notification');
									fn.loadData('archive');
									sidebarPanel.items.get('container').items.get('sideBtn1').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn2').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn3').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn5').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn6').enableToggle = false;
									
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}, 
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn5',
								style: 'background: #EAEBEE; border:none;',
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-notification.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'NOTIFICATION'),
								toggleHandler: function (me, state) {
									if(!state) return;

									contentPanel.getLayout().setActiveItem(4);
									clearInterval(fn.statisticsChartId);
									
									fn.loadData('serversettings');
									fn.loadData('notification');
									fn.loadData('archive');
									
									sidebarPanel.items.get('container').items.get('sideBtn1').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn2').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn3').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn4').enableToggle = false;
									sidebarPanel.items.get('container').items.get('sideBtn6').enableToggle = false;
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}, 
							{
								xtype: 'asSysSideBtn',
								itemId: 'sideBtn6',
								style: 'background: #EAEBEE; border:none;',
								cls: 'syslogServer',
								height: 38,
								icon: fn.imgUrl + 'icon-fn-history.png',
								iconAlign: 'left',
								textAlign: 'left',
								scale: 'medium',
								enableToggle: true,
								allowDepress: false,
								toggleGroup: 'toggle-sys-sidebar',
								text: _S('SYSLOG_SERVER', 'HISTORY'),
								toggleHandler: function (me, state) {
									if(!state) return;

									contentPanel.getLayout().setActiveItem(5);
									clearInterval(fn.statisticsChartId);
									
									fn.activeItem = 5;
									contentPanel.items.get('historyTabPanel').items.get('historyTab').items.get('historyPanel').items.get('grid').store.load();
								},
								listeners: {
									click: function(btn) {
										
										if(!fn.checkSettings() && btn.enableToggle == false) {
											var confirmWindow = new AS.ARC.msgWindow({
												title: _S('COMMON', 'CONFIRMATION'),
												parentWin: fn.win,
												width: 400,
												height: 160,
												iconType: 'question', // info, question, warning
												asItems: [{
													xtype: 'displayfield',
													value: _S('COMMON', 'CONFIRM_SETTING_MODIFY')
												}],
												fbar: [{
													text: _S('COMMON', 'YES'),
													handler: function () {						
														btn.ownerCt.items.get('sideBtn1').enableToggle = true;
														btn.ownerCt.items.get('sideBtn2').enableToggle = true;
														btn.ownerCt.items.get('sideBtn3').enableToggle = true;
														btn.ownerCt.items.get('sideBtn4').enableToggle = true;
														btn.ownerCt.items.get('sideBtn5').enableToggle = true;
														btn.ownerCt.items.get('sideBtn6').enableToggle = true;
														confirmWindow.close();
														btn.el.dom.click();
													},
													scope: this
												}, {
													text: _S('COMMON', 'NO'),
													handler: function () {						

														confirmWindow.close();
													},
													scope: this
												}]
											});

											confirmWindow.show();
											
											
										} else if(fn.checkSettings() && btn.enableToggle == false){
											btn.enableToggle = true;
											btn.el.dom.click();
										}
									}
								}
							}
					]
				}
			]
		});

		var contentPanel = Ext.create(Ext.panel.Panel, {
			itemId: 'content',
			region: 'center',
			bodyStyle: 'height: 550px !important',
			layout: 'card',
			activeItem: 0,
			items: [
				fn.getOverviewPanel(),
				fn.getLogPanel(),
				fn.getServerSettingsPanel(),
				fn.getArchivePanel(),
				fn.getNotificationPanel(),
				fn.getHistoryPanel()
			]
		});

		fn.panel = Ext.create(Ext.panel.Panel, {
			itemId: 'main',
			layout: 'border',
			items: [
				sidebarPanel,
				contentPanel
			]
		});

		return fn.panel;
	},
	
	loadData: function(page) {
		var fn = this;
		var contentPanel = fn.panel.items.get('content');
		var generalContent = contentPanel.items.get('server-panel').items.get('general-tab').items.get('generalContent');
		var archivePanel = contentPanel.items.get('archiveTabPanel').items.get('archiveTab').items.get('archivePanel');
		var notificationPanel = contentPanel.items.get('notificationTabPanel').items.get('notificationTab').items.get('notification');
		var noEmailNotification = contentPanel.items.get('notificationTabPanel').items.get('notificationTab').items.get('no_email');
				
		if (page == 'serversettings') {
			
			var enable_server = generalContent.items.get('fieldset1').items.get('enable_server');
			var enable_tcp = generalContent.items.get('fieldset1').items.get('enable_tcp');
			var enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl');
			var tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port');
			var enable_udp = generalContent.items.get('fieldset1').items.get('enable_udp');
			var udp_port = generalContent.items.get('fieldset1').items.get('udp_port');
					
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Get_Setting'}),
				method: 'post',
				success: function (json, opts) {
					
					if(json.enable_server == 1) {
								
						enable_server.setValue(true);
						fn.uiChecker.enable_syslog_server = true;
					} else {
						enable_server.setValue(false);
						fn.uiChecker.enable_syslog_server = false;
					}
							
					if(json.enable_tcp == 1) {
						enable_tcp.setValue(true);
						fn.uiChecker.enable_tcp = true;
					} else {
						enable_tcp.setValue(false);
						fn.uiChecker.enable_tcp = false;
					}
							
					tcp_port.setValue(json.tcp_port);
					fn.uiChecker.tcp_port = json.tcp_port;
							
					if(json.enable_ssl == 1) {
						enable_ssl.setValue(true);
						fn.uiChecker.enable_ssl = true;
					} else {
						enable_ssl.setValue(false);
						fn.uiChecker.enable_ssl = false;
					}
							
					if(json.enable_udp == 1) {
						enable_udp.setValue(true);
						fn.uiChecker.enable_udp = true;
					} else {
						enable_udp.setValue(false);
						fn.uiChecker.enable_udp = false;
					}
					
					tcp_port.clearInvalid();
					udp_port.clearInvalid();
					
					udp_port.setValue(json.udp_port);
					fn.uiChecker.udp_port = json.udp_port;
				},
				failure: function (json, opts) {
					AS.ARC.util.showMsgWindow({
						5000: _S('ERROR', 'SESSION_TIMEOUT'),
						5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE')
					}, json, fn.win);
				}
			});
			
			
		} else if (page == 'archive') {
			var path = archivePanel.items.get('fs1').items.get('container1').items.get('path');
			var name = archivePanel.items.get('fs1').items.get('container2').items.get('name');
			var format = archivePanel.items.get('fs1').items.get('container2').items.get('format');
			var volume = archivePanel.items.get('fs2').items.get('container3').items.get('val');
			var count = archivePanel.items.get('fs2').items.get('container4').items.get('val');
			var period = archivePanel.items.get('fs2').items.get('container5').items.get('val');

			var volumeVal = volume.getValue();
			var countVal = count.getValue();
			var periodVal = period.getValue();

			var checkboxVolume = archivePanel.items.get('fs2').items.get('container3').items.get('checkbox');
			var checkboxCount = archivePanel.items.get('fs2').items.get('container4').items.get('checkbox');
			var checkboxPeriod = archivePanel.items.get('fs2').items.get('container5').items.get('checkbox');

			
			if(!checkboxVolume.checked) {
				volumeVal = 0;
			}

			if(!checkboxCount.checked) {
				countVal = 0;
			}

			if(!checkboxPeriod.checked) {
				periodVal = 0;
			}
							
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Archive', tab: 'Get_Setting'}),
				method: 'post',
				success: function (json, opts) {
					
					path.setValue(json.archive_location);
					fn.uiChecker.default_path = json.archive_location;
					
					name.setValue(json.archive_name);
					fn.uiChecker.log_name = json.archive_name;
					
					format.setValue(json.archive_format);
					fn.uiChecker.format = json.archive_format;
					
					volume.setValue(json.archive_size);
					fn.uiChecker.size_value = json.archive_size;
					
					count.setValue(json.archive_number);
					fn.uiChecker.count_value = json.archive_number;
					
					period.setValue(json.archive_date);
					fn.uiChecker.earlier_value = json.archive_date;
					

					if(json.archive_size == 0) {
						checkboxVolume.setValue(false);
						fn.uiChecker.enable_size = false;
						
						volume.setValue(1);
						fn.uiChecker.size_value = 1;
						
						volume.disable();
					} else {
						checkboxVolume.setValue(true);
						fn.uiChecker.enable_size = true;
						
						volume.enable();
					}

					if(json.archive_number == 0) {
						checkboxCount.setValue(false);
						fn.uiChecker.enable_count = false;
						
						count.setValue(1);
						fn.uiChecker.count_value = 1;
						
						count.disable();
					} else {
						checkboxCount.setValue(true);
						fn.uiChecker.enable_count = true;
						
						count.enable();
					}

					if(json.archive_date == 0) {
						checkboxPeriod.setValue(false);
						fn.uiChecker.enable_earlier = false;
						
						period.setValue(1);
						fn.uiChecker.earlier_value = 1;
						
						period.disable();
					} else {
						checkboxPeriod.setValue(true);
						fn.uiChecker.enable_earlier = true;
						
						period.enable();
					}
				},
				failure: function (json, opts) {

				}
			});
			
			
		
		} else if (page == 'notification') {
			var enable_number = notificationPanel.items.get('fs').items.get('container1').items.get('limitCheck');
			var number = notificationPanel.items.get('fs').items.get('container1').items.get('limitVal');
			var enable_level = notificationPanel.items.get('fs').items.get('container2').items.get('severityCheck');
			var level = notificationPanel.items.get('fs').items.get('container2').items.get('severityVal');
			var enable_keyword = notificationPanel.items.get('fs').items.get('container3').items.get('keywordCheck');
			var keyword_count = 0;
			var keyword1 = notificationPanel.items.get('fs').items.get('container3').items.get('keyword1');
			var keyword2 = notificationPanel.items.get('fs').items.get('keyword2');
			var keyword3 = notificationPanel.items.get('fs').items.get('keyword3');
			
					
			
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Notifacation', tab: 'Get_Setting'}),
				method: 'post',
				success: function (json, opts) {

				if (json.notifacation == 0) {
					if (notificationPanel != undefined) {
						notificationPanel.el.mask();
						noEmailNotification.show();
					}
				} else {
												
					if(json.enable_number == 0) {
						enable_number.setValue(false);
						fn.uiChecker.enable_limit = false;					
						number.disable();
					} else {
						enable_number.setValue(true);
						fn.uiChecker.enable_limit = true;					
						number.enable();
					}

					if(json.enable_level == 0) {
						enable_level.setValue(false);
						fn.uiChecker.enable_severity = false;				
						level.disable();
					} else {
						enable_level.setValue(true);
						fn.uiChecker.enable_severity = true;					
						level.enable();
					}

					if(json.enable_keyword == 0) {
						enable_keyword.setValue(false);
						fn.uiChecker.enable_keyword = false;
													
						keyword1.disable();
						keyword2.disable();
						keyword3.disable();
					} else {
						enable_keyword.setValue(true);
						fn.uiChecker.enable_keyword = true;
													
						keyword1.enable();
						keyword2.enable();
						keyword3.enable();
					}

						number.setValue(json.number);
						fn.uiChecker.limit_value = json.number;
						level.setValue(json.level);
						fn.uiChecker.severity_value = json.level;
												
						keyword1.setValue(json.keyword1);
						if (json.keyword1 == undefined) {
							fn.uiChecker.keyword1 = '';
						} else {
							fn.uiChecker.keyword1 = json.keyword1;
						}
												
												
						keyword2.setValue(json.keyword2);
						if (json.keyword2 == undefined) {
							fn.uiChecker.keyword2 = '';
						} else {
							fn.uiChecker.keyword2 = json.keyword2;
						}
												
						keyword3.setValue(json.keyword3);
						if (json.keyword3 == undefined) {
							fn.uiChecker.keyword3 = '';
						} else {
							fn.uiChecker.keyword3 = json.keyword3;
						}
												
						if (notificationPanel != undefined) {
							notificationPanel.el.unmask();
							noEmailNotification.hide();
						}
					}
				},
				failure: function (json, opts) {
					AS.ARC.util.showMsgWindow({
					5000: _S('ERROR', 'SESSION_TIMEOUT'),
					5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
				}, json, fn.win);
										}
			});
					
		}
	},
	
	checkSettings: function() {
		var fn = this;
		var uiChecker = {
			//server_settings
			enable_syslog_server: false,
			enable_tcp: false,
			tcp_port: 0,
			enable_ssl: false,
			enable_udp: false,
			udp_port: 0,

			//archive
			default_path: '',
			log_name: '',
			format: 0,
			enable_size: false,
			size_value: 0,
			enable_count: false,
			count_value: 0,
			enable_earlier: false,
			earlier_value: 0,

			//notification
			enable_limit: false,
			limit_value: 0,
			enable_severity: false,
			severity_value: 0,
			enable_keyword: false,
			keyword1: '',
			keyword2: '',
			keyword3: ''
		};
		
		var propertyAry = [
			'enable_syslog_server',
			'enable_tcp',
			'tcp_port',
			'enable_ssl',
			'enable_udp',
			'udp_port',
			'default_path',
			'log_name',
			'format',
			'enable_size',
			'size_value',
			'enable_count',
			'count_value',
			'enable_earlier',
			'earlier_value',
			'enable_limit',
			'limit_value',
			'enable_severity',
			'severity_value',
			'enable_keyword',
			'keyword1',
			'keyword2',
			'keyword3'
		];
		
		var contentPanel = fn.panel.items.get('content');
		var generalContent = contentPanel.items.get('server-panel').items.get('general-tab').items.get('generalContent');
		var archivePanel = contentPanel.items.get('archiveTabPanel').items.get('archiveTab').items.get('archivePanel');
		var notificationPanel = contentPanel.items.get('notificationTabPanel').items.get('notificationTab').items.get('notification');
		
		//server settings components
		var enable_syslog_server = generalContent.items.get('fieldset1').items.get('enable_server');
		uiChecker.enable_syslog_server = enable_syslog_server.getValue();
		
		var enable_tcp = generalContent.items.get('fieldset1').items.get('enable_tcp');
		uiChecker.enable_tcp = enable_tcp.getValue();
		
		var enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl');
		uiChecker.enable_ssl = enable_ssl.getValue();
		
		var tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port');
		uiChecker.tcp_port = tcp_port.getValue();
		
		var enable_udp = generalContent.items.get('fieldset1').items.get('enable_udp');
		uiChecker.enable_udp = enable_udp.getValue();
		
		var udp_port = generalContent.items.get('fieldset1').items.get('udp_port');
		uiChecker.udp_port = udp_port.getValue();
		
		//archive components
		var default_path = archivePanel.items.get('fs1').items.get('container1').items.get('path');
		uiChecker.default_path = default_path.getValue();
		
		var log_name = archivePanel.items.get('fs1').items.get('container2').items.get('name');
		uiChecker.log_name = log_name.getValue();
		
		var format = archivePanel.items.get('fs1').items.get('container2').items.get('format');
		uiChecker.format = format.getValue();
		
		var size_value = archivePanel.items.get('fs2').items.get('container3').items.get('val');
		uiChecker.size_value = size_value.getValue();
		
		
		var count_value = archivePanel.items.get('fs2').items.get('container4').items.get('val');
		uiChecker.count_value = count_value.getValue();
		
		var earlier_value = archivePanel.items.get('fs2').items.get('container5').items.get('val');
		uiChecker.earlier_value = earlier_value.getValue();
		

		var enable_size = archivePanel.items.get('fs2').items.get('container3').items.get('checkbox');
		uiChecker.enable_size = enable_size.getValue();
		
		var enable_count = archivePanel.items.get('fs2').items.get('container4').items.get('checkbox');
		uiChecker.enable_count = enable_count.getValue();
		
		var enable_earlier = archivePanel.items.get('fs2').items.get('container5').items.get('checkbox');
		uiChecker.enable_earlier = enable_earlier.getValue();
		
		
		//notification components
		var enable_limit = notificationPanel.items.get('fs').items.get('container1').items.get('limitCheck');
		uiChecker.enable_limit = enable_limit.getValue();
		
		var limit_value = notificationPanel.items.get('fs').items.get('container1').items.get('limitVal');
		uiChecker.limit_value = limit_value.getValue();
		
		var enable_severity = notificationPanel.items.get('fs').items.get('container2').items.get('severityCheck');
		uiChecker.enable_severity = enable_severity.getValue();
		
		var severity_value = notificationPanel.items.get('fs').items.get('container2').items.get('severityVal');
		uiChecker.severity_value = severity_value.getValue();
		
		var enable_keyword = notificationPanel.items.get('fs').items.get('container3').items.get('keywordCheck');
		uiChecker.enable_keyword = enable_keyword.getValue();
		
		var keyword_count = 0;
		var keyword1 = notificationPanel.items.get('fs').items.get('container3').items.get('keyword1');
		uiChecker.keyword1 = keyword1.getValue();
		
		var keyword2 = notificationPanel.items.get('fs').items.get('keyword2');
		uiChecker.keyword2 = keyword2.getValue();
		
		var keyword3 = notificationPanel.items.get('fs').items.get('keyword3');
		uiChecker.keyword3 = keyword3.getValue();
		
		
		for(var i = 0; i < propertyAry.length; i ++) {
			if (fn.uiChecker[propertyAry[i]] != uiChecker[propertyAry[i]]) {
				return false;
			}
		}
		
		return true;
	},
	
	loadPieChart: function(activeIndex, chart) {
		
		var fn = this;
		
		if (activeIndex == 1) {
			
			fn.panel.el.mask(_S('COMMON', 'LOADING'));
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Overview', tab: 'Group', group: 1}),
				method: 'post',
				success: function (json, opts) {
								
					var ary = [];
								
					if (json.device.length != 0) {
						if (json.device.length > 4) {

							var count0 = json.device[0].count / json.count * 100;
							var count1 = json.device[1].count / json.count * 100;
							var count2 = json.device[2].count / json.count * 100;
							var otherCount = ((json.count - (json.device[0].count + json.device[1].count + json.device[2].count)) / json.count) * 100;

							if (count0 < 1) {
								count0 = 1;
							}

							if (count1 < 1) {
								count1 = 1;
							}

							if (count2 < 1) {
								count2 = 1;
							}

							if (otherCount < 1) {
								otherCount = 1;
							}

							if (json.device[0].count != 0) {
								ary.push({count: count0, fromhostname: json.device[0].fromhostname + ' - ' + json.device[0].percentage + '%'});
							}

							if (json.device[1].count != 0) {
								ary.push({count: count1, fromhostname: json.device[1].fromhostname + ' - ' + json.device[1].percentage + '%'});
							}

							if (json.device[2].count != 0) {
								ary.push({count: count2, fromhostname: json.device[2].fromhostname + ' - ' + json.device[2].percentage + '%'});
							}

							if (json.count - (json.device[0].count + json.device[1].count + json.device[2].count) != 0) {
								ary.push({count: otherCount, fromhostname: 'Others' + ' - ' + (100 - json.device[0].percentage - json.device[1].percentage - json.device[2].percentage).toFixed(2) + '%'});
							}
										
							chart.show();
							chart.store.loadData(ary, false);
							fn.panel.el.unmask();

						} else {
							for(var i = 0; i < json.device.length; i ++) {

								var count = json.device[i].count / json.count * 100;
								if (count < 1) {
									count = 1;
								}

								if (json.device[i].count != 0) {
									ary.push({count: count, fromhostname: json.device[i].fromhostname + ' - ' + json.device[i].percentage + '%'});
								}
							}
							chart.ownerCt.el.unmask();
							chart.show();
							chart.store.loadData(ary, false);
							fn.panel.el.unmask();
						}
					} else {
						chart.ownerCt.el.mask(_S('COMMON', 'EMPTY_NO_DATA'), 'as-mask-msg');
						chart.hide();
						fn.panel.el.unmask();
					}
								
			},
			failure: function (json, opts) {
									
			}
		});
			
		} else if (activeIndex == 2) {
			fn.panel.el.mask(_S('COMMON', 'LOADING'));
			AS.ARC.ajax({
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Overview', tab: 'Group', group: 0}),
				method: 'post',
				success: function (json, opts) {
								
					var ary = [];
								
					var total = json.data[0].count + json.data[1].count + json.data[2].count + json.data[3].count;
					var cri = (json.data[0].count / total) * 100;
					var err = (json.data[1].count / total) * 100;
					var warn = (json.data[2].count / total) * 100;
					var info = (json.data[3].count / total) * 100;
								
					if (total != 0) {
						if (cri < 1) {
							cri = 1;
						}

						if (err < 1) {
							err = 1;
						}

						if (warn < 1) {
							warn = 1;
						}

						if (info < 1) {
							info = 1;
						}

						if (json.data[0].count != 0) {
							ary.push({count: cri, level: json.data[0].level + ' - ' + json.data[0].percentage + '%'});
						}

						if (json.data[1].count != 0) {
							ary.push({count: err, level: json.data[1].level + ' - ' + json.data[1].percentage + '%'});
						}

						if (json.data[2].count != 0) {
							ary.push({count: warn, level: json.data[2].level + ' - ' + json.data[2].percentage + '%'});
						}

						if (json.data[3].count != 0) {
							ary.push({count: info, level: json.data[3].level + ' - ' + json.data[3].percentage + '%'});
						}
									
						chart.ownerCt.el.unmask();
						chart.show();
						chart.store.loadData(ary, false);
						fn.panel.el.unmask();
					} else {
						chart.ownerCt.el.mask(_S('COMMON', 'EMPTY_NO_DATA'), 'as-mask-msg');
						chart.hide();
						fn.panel.el.unmask();
					}
				},
				failure: function (json, opts) {
						
				}
			});
		
		}
	},

	getOverviewPanel: function () {
		var fn = this;
		
		var store = Ext.create('Ext.data.Store', {
			autoLoad: false,
			fields: ['count', 'fromhostname'],
			data: [{
				name: '',
				value: 100    // another value diferent to "0"
			}]
		});
		
		var chartstore = Ext.create('Ext.data.Store', {
			fields: ['count', 'time', 'index'],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, {
					act: 'Overview',
					tab: 'Statistics'
				}),
				reader: {
					type: 'json',
					root: 'data'
				}
			},
			params: {
				time: 5
			},
			sorters: [{property: 'index',direction: 'DESC' }],
			listeners: {
				beforeload: function() {
					//logGrid.el.mask(_S('COMMON','LOADING'));
					//overview.items.get('chartcontainer').items.get('chart').el.mask(_S('COMMON', 'LOADING'));
				},
				load: function() {
					//logGrid.el.unmask();
					//overview.items.get('chartcontainer').items.get('chart').el.unmask();
				}
			}
		});
		
		
		var levelstore = Ext.create('Ext.data.Store', {
			autoLoad: false,
			fields: ['count', 'level'],
			data: [{
				name: '',
				value: 100    // another value diferent to "0"
			}]
		});
		
		var statisticsChart = Ext.create('Ext.chart.Chart', {
			itemId: 'statisticschart',
			store: chartstore,
			width: 660,
   			height: 425,
			minHeight: 425,
        	minWidth: 550,
			theme: 'Category1',
			axes: [
				{
					title: _S('SYSLOG_SERVER', 'COUNT'),
					type: 'Numeric',
					position: 'left',
					fields: ['count'],
					minimum: 0,
					maximum: 10
				}, 
				{
					title: _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES'),
					type: 'Category',
					position: 'bottom',
					fields: ['time']
				}
			],
			series: [
				{
					type: 'line',
					xField: 'time',
					yField: 'count'
				}
			],
			listeners: {
				render: function() {
					
					fn.statisticsChartId = setInterval(function() {
						statisticsChart.loadData();
					}, 20000);
					
				}
			},
			
			loadData: function(param) {
				
				var fn = fn;
				if (param) {
					statisticsChart.store.load({
						scope: this,
						params: param,
						callback: function(records, operation, success) {

							var yAxis = statisticsChart.axes.items[0];
							var dataAry = [];
							
							Ext.each(records, function(record) {
    							dataAry.push(record.data.count);
							})
							
							var max = dataAry.max();
							// set range of y axis, 50 100 500 1000,...
							if (max > 10) {
								var firstNum = parseInt(Math.floor(max / 10).toString().substr(0,1)),
									pow = Math.pow(10, max.toString().length - 1);

								if (firstNum < 5) {
									yAxis.maximum = 5 * pow;
								} else {
									yAxis.maximum = 10 * pow;
								}
								statisticsChart.redraw();
							}
							

						}
					});
				} else {
					statisticsChart.store.load({
						scope: this,
						callback: function(records, operation, success) {

							var yAxis = statisticsChart.axes.items[0];
							var dataAry = [];
							
							Ext.each(records, function(record) {
    							dataAry.push(record.data.count);
							})
							
							var max = dataAry.max();

							// set range of y axis, 50 100 500 1000,...
							if (max > 10) {
								var firstNum = parseInt(Math.floor(max / 10).toString().substr(0,1)),
									pow = Math.pow(10, max.toString().length - 1);

								if (firstNum < 5) {
									yAxis.maximum = 5 * pow;
								} else {
									yAxis.maximum = 10 * pow;
								}
								statisticsChart.redraw();
							}
							
							
						}
					});
				}
				
			}
		});
		
		var levelChart = Ext.create('Ext.chart.Chart', {
			itemId: 'levelchart',
			width: 675,
   			height: 425,
			border: 0,
			insetPadding: 60,
			//animate: true,
			shadow: false,
			theme: 'Base:gradients',
			store: levelstore,
			legend: {
				position: 'right'
			},
			series: [
				{
					type: 'pie',
					field: 'count',
					showInLegend: true,
					donut: false,
					highlight: {
						segment: {
							margin: 20
						}
					},
					label: {
						field: 'level',
						//display: 'rotate',
						contrast: true,
						font: '12px Arial'
					}
				}
			],
			listeners: {
				afterrender: function(chart) {
					
					Ext.each(chart.legend.items, function(item) {
    					item.un("mousedown", item.events.mousedown.listeners[0].fn);
					});
					
					
				}
			}
		});
		
		var deviceChart = Ext.create('Ext.chart.Chart', {
			itemId: 'devicechart',
			width: 675,
   			height: 425,
			border: 0,
			insetPadding: 60,
			//animate: true,
			shadow: false,
			store: store,
			legend: {
				position: 'right'
			},
			series: [
				{
					type: 'pie',
					field: 'count',
					showInLegend: true,
					donut: false,
					highlight: {
						segment: {
							margin: 20
						}
					},
					label: {
						field: 'fromhostname',
						//display: 'rotate',
						contrast: true,
						font: '12px Arial'
					}
				}
			]
		});
		
		var statisticsTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'statistics-tab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'LOG_COUNT'),
			items: [
				{
					xtype: 'combobox',
					itemId: 'combobox',
					store: {
						fields: ['value', 'text'],
						data: [
							{'value': 5, 'text': _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES')},
							{'value': 6, 'text': _S('SYSLOG_SERVER', 'PAST_ONE_HOUR')},
							{'value': 7, 'text': _S('SYSLOG_SERVER', 'PAST_SIX_HOURS')},
							{'value': 8, 'text': _S('SYSLOG_SERVER', 'PAST_ONE_DAY')}
						]
					},
					editable: false,
					value: '5',
					triggerAction: 'all',
					valueField: 'value',
					displayField: 'text',
					listeners: {
						change: function(combo, value) {
							if (value == 5) {
								
								var time = { 
									time: 5
								}
								
								statisticsChart.store.getProxy().extraParams = time;
								statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_SIX_MINUTES');
								
							} else if (value == 6) {
								
								var time = { 
									time: 6
								}
								
								statisticsChart.store.getProxy().extraParams = time;
								statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_ONE_HOUR');
							} else if (value == 7) {
								
								var time = { 
									time: 7
								}
								
								statisticsChart.store.getProxy().extraParams = time;
								statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_SIX_HOURS');
							} else {
								
								var time = { 
									time: 8
								}
								
								statisticsChart.store.getProxy().extraParams = time;
								
								statisticsChart.axes.get('bottom').title = _S('SYSLOG_SERVER', 'PAST_ONE_DAY');
							}
							
							statisticsChart.loadData();
							
						}
					}
				},
				statisticsChart
			]

		});

		var groupTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'device-tab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'VIEW_BY_DEVICE'),
			items: [
				deviceChart
			]

		});
		
		
		var levelTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'level-tab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'VIEW_BY_LEVEL'),
			items: [
				levelChart
			]
		});


		return {
			xtype: 'tabpanel',
			itemId: 'tabpanel',
			items: [
				statisticsTab,
				groupTab,
				levelTab
			],
			listeners: {
				tabchange: function(tabpanel) {
					var activeIndex = tabpanel.items.indexOf(tabpanel.getLayout().activeItem);
					
					if (activeIndex == 0) {
						statisticsChart.loadData({
							time: statisticsTab.items.get('combobox').getValue()
						});
						fn.statisticsChartId = setInterval(function() {
							statisticsChart.loadData({						
								time: statisticsTab.items.get('combobox').getValue()						
							});
						}, 20000);
					} else if (activeIndex == 1) {
						
						clearInterval(fn.statisticsChartId);
						fn.loadPieChart(1, deviceChart);
						
					} else if (activeIndex == 2) {
						clearInterval(fn.statisticsChartId);
						fn.loadPieChart(2, levelChart);
						
						
					}
				}
			}
			
		}
		
		
	},

	getLogPanel: function () {
		var fn = this;
		
		var getAdvanceSearchWin = function() {
			
			var advanceSearchWin = Ext.create('AS.ARC.subWindow', {
				itemId: 'advanceSearchWin',
				title: _S('SYSLOG_SERVER', 'ADVANCED_SEARCH'),
				width: 550,
				height: 415,
				layout: 'fit',
				parentWin: fn.win,
				fbar: [
					{
						xtype: 'button',
						itemId: 'search',
						text: _S('SYSLOG_SERVER', 'SEARCH'),
						handler: function() {
							var msg = advanceSearchWin.items.get('container').items.get('keyword').getValue();
							var fromhostname = advanceSearchWin.items.get('container').items.get('device').getValue();
							var level = advanceSearchWin.items.get('container').items.get('level').getValue();
							var facility = advanceSearchWin.items.get('container').items.get('facility').getValue();
							var time = advanceSearchWin.items.get('container').items.get('time').getValue();
							var start_time = advanceSearchWin.items.get('container').items.get('startTime').getSubmitValue();
							var end_time = advanceSearchWin.items.get('container').items.get('endTime').getSubmitValue();
							var progname = advanceSearchWin.items.get('container').items.get('progname').getValue();
							
							
							var params = {
								tab: 'Search',
								msg: msg,
								fromhostname: fromhostname,
								level: level,
								facility: facility,
								time: time,
								start_time: start_time,
								end_time: end_time,
								progname: progname
							};
							
							if (logGrid.store.getProxy().extraParams.logfile) {
								Ext.apply(params, {
									logfile: logGrid.store.getProxy().extraParams.logfile
								});
							}
							
							if(msg == '') {
								delete params.msg;
								
							}
							
							if(fromhostname == '') {
								delete params.fromhostname;
							}
							
							if(level == '') {
								delete params.level;	
							}
							
							if(facility == '') {
								delete params.facility;
							}
							
							if(progname == '') {
								delete params.progname;
							}
							
							if (start_time == '') {
								delete params.start_time;
							}
							
							if (end_time == '') {
								delete params.end_time;
							}
						
						
							logGrid.store.getProxy().extraParams = params;
							logGrid.store.load();
							
							advanceSearchWin.close();
							fn.panel.el.unmask();
						}

					}, 
					{
						xtype: 'button',
						text: _S('SYSLOG_SERVER', 'RESET'),
						handler: function() {
							var msg = advanceSearchWin.items.get('container').items.get('keyword');
							var fromhostname = advanceSearchWin.items.get('container').items.get('device');
							var level = advanceSearchWin.items.get('container').items.get('level');
							var facility = advanceSearchWin.items.get('container').items.get('facility');
							var time = advanceSearchWin.items.get('container').items.get('time');
							var start_time = advanceSearchWin.items.get('container').items.get('startTime');
							var end_time = advanceSearchWin.items.get('container').items.get('endTime');
							var progname = advanceSearchWin.items.get('container').items.get('progname');
							
							msg.setValue('');
							fromhostname.setValue('');
							level.setValue('');
							facility.setValue('');
							time.setValue(0);
							start_time.setValue('');
							end_time.setValue('');
							progname.setValue('');
							advanceSearchWin.items.get('container').items.get('startTime').disable();
							advanceSearchWin.items.get('container').items.get('endTime').disable();
						}
					}, 
					{
						xtype: 'button',
						text: _S('COMMON', 'CANCEL'),
						handler: function() {
							advanceSearchWin.close();
						}
					}
				],
				items: [
					{
						xtype: 'panel',
						itemId: 'container',
						bodyStyle: 'padding: 15px;',
						//style: 'background-color: white;',
						items: [
							{
								xtype: 'textfield',
								labelWidth: 200,
								itemId: 'keyword',
								fieldLabel: _S('SYSLOG_SERVER', 'KEYWORD'),
							}, 
							{
								xtype: 'combobox',
								itemId: 'device',
								store: {
									fields: ['fromhostname'],
									proxy: {
										type: 'ajax',
										url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, {
											act: 'Overview',
											tab: 'Group',
											group: 1
										}),
										reader: {
											type: 'json',
											root: 'device'
										}
									},
								},
								fieldLabel: _S('SYSLOG_SERVER', 'DEVICE'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'fromhostname',
								displayField: 'fromhostname'

							}, 
							{
								xtype: 'combobox',
								itemId: 'level',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': '', 'text': _S('COMMON', 'ALL')},
										{'value':'0', 'text':'Emergency'},
										{'value':'1', 'text':'alert'},
										{'value': '2', 'text': 'critical'},
										{'value': '3', 'text': 'error'},
										{'value': '4', 'text': 'warning'},
										{'value': '5', 'text': 'notice'},
										{'value': '6', 'text': 'info'},
										{'value': '7', 'text': 'debug'}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'LEVEL'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text'

							}, 
							{
								xtype: 'combobox',
								itemId: 'facility',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': '', 'text': _S('COMMON', 'ALL')},
										{'value':'0', 'text':'kern'},
										{'value':'1', 'text':'user'},
										{'value':'2', 'text':'mail'},
										{'value':'3', 'text':'daemon'},
										{'value':'4', 'text':'auth'},
										{'value':'5', 'text':'syslog'},
										{'value':'6', 'text':'lpr'},
										{'value':'7', 'text':'news'},
										{'value':'8', 'text':'uucp'},
										{'value':'9', 'text':'cron'},
										{'value':'10', 'text':'security'},
										{'value':'11', 'text':'ftp'},
										{'value':'12', 'text':'ntp'},
										{'value':'13', 'text':'logaudit'},
										{'value':'14', 'text':'logalert'},
										{'value':'15', 'text':'clock'},
										{'value':'16', 'text':'local0'},
										{'value':'17', 'text':'local1'},
										{'value':'18', 'text':'local2'},
										{'value':'19', 'text':'local3'},
										{'value':'20', 'text':'local4'},
										{'value':'21', 'text':'local5'},
										{'value':'22', 'text':'local6'},
										{'value':'23', 'text':'local7'}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'FACILITY'),
								labelWidth: 200,
								editable: false,
								value: '',
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text'
							},
							{
								xtype: 'combobox',
								itemId: 'time',
								store: {
									fields: ['value', 'text'],
									data: [
										{'value': 0, 'text': _S('COMMON', 'ALL')},
										{'value': 1, 'text':'Past 1 day'},
										{'value': 2, 'text': 'Past 1 week'},
										{'value': 3, 'text': 'Past 1 month'},
										{'value': 4, 'text': 'Custom'}
									]
								},
								fieldLabel: _S('SYSLOG_SERVER', 'TIME_PERIOD'),
								labelWidth: 200,
								editable: false,
								value: 0,
								triggerAction: 'all',
								valueField: 'value',
								displayField: 'text',
								listeners: {
									change: function(combo, value) {

										if(value == 4) {
											advanceSearchWin.items.get('container').items.get('startTime').enable();
											advanceSearchWin.items.get('container').items.get('endTime').enable();
										} else {
											advanceSearchWin.items.get('container').items.get('startTime').disable();
											advanceSearchWin.items.get('container').items.get('endTime').disable();
										}
									}
								}
							}, 
							{
								xtype: 'datefield',
								format: 'Y-m-d',
								itemId: 'startTime',
								disabled: true,
								style: 'margin-left: 10px',
								fieldLabel: _S('SYSLOG_SERVER', 'START_TIME'),
								labelWidth: 190
							}, 
							{
								xtype: 'datefield',
								format: 'Y-m-d',
								itemId: 'endTime',
								disabled: true,
								style: 'margin-left: 10px',
								fieldLabel: _S('SYSLOG_SERVER', 'END_TIME'),
								labelWidth: 190
							}, 
							{
								xtype: 'textfield',
								itemId: 'progname',
								fieldLabel: _S('SYSLOG_SERVER', 'PROGNAME'),
								labelWidth: 200

							}
							
						]
					}
				]
			});
			
			advanceSearchWin.show();
		};
		
		var logTopCt = Ext.create(Ext.container.Container, {
			itemId: 'log-topct',
			layout: 'hbox',
			items: [
				{
					xtype: 'displayfield',
					itemId: 'phy_path',
					hidden: true,
					value: ''
				}, 
				/*{
					xtype: 'button',
					itemId: 'refresh',
					text: _S('SYSLOG_SERVER', 'REFRESH'),
					minWidth: 100,
					handler: function() {
						logGrid.store.getProxy().extraParams = {
							tab: 'List'
						};
						logGrid.store.load();
						}

				},*/ 
				{
					xtype: 'splitbutton',
					itemId: 'export',
					text: _S('SYSLOG_SERVER', 'EXPORT'),
					minWidth: 100,
					onClick: function () {
						var btn = this;

						// Menu would show at wrong position. If create at definition.
						// Because of this. Creating menu when btn be pressed.
						if( !btn.menu ){
							btn.menu =  new Ext.menu.Menu({
								items: [{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'HTML'),
									icon: fn.imgUrl + 'html-icon.png',
									handler: function(){
										
										var download = Ext.create('Ext.form.FormPanel', {
											items: [{ xtype: 'filefield' }]
										}),
											uform = download.getForm();

										var doSubmit = function () {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, { act: 'List', tab: 'Export', format: 'html'}),
												success: function (fp, o) {
												},
												failure: function (form, action) {
													var json = Ext.decode(action.response.responseText);
													AS.ARC.util.showMsgWindow({
														5005: _S('SYSLOG_SERVER', 'LOG_NO_DATA')
													}, json, fn.win);

												}
											});
										}

										doSubmit();		
									}
								},
								{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'CSV'),
									icon: fn.imgUrl + 'csv-icon.png',
									handler: function(){
										var download = Ext.create('Ext.form.FormPanel', {
											items: [{ xtype: 'filefield' }]
										}),
											uform = download.getForm();

										var doSubmit = function () {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, { act: 'List', tab: 'Export', format: 'csv'}),
												success: function (fp, o) {
												},
												failure: function (form, action) {
													var json = Ext.decode(action.response.responseText);
													AS.ARC.util.showMsgWindow({
														5005: _S('SYSLOG_SERVER', 'LOG_NO_DATA')
													}, json, fn.win);

												}
											});
										}

										doSubmit();
									}
								}]
							});
						}// end if
						btn.menu.showBy( btn, 'tl-bl' );
					}
				},
				{
					xtype: 'splitbutton',
					itemId: 'import',
					//text: _S('SYSLOG_SERVER', 'LATEST_LOG'),
					text: _S('SYSLOG_SERVER', 'LATEST_LOG'),
					minWidth: 200,
					maxWidth: 200,
					onClick: function () {
						var btn = this;

						// Menu would show at wrong position. If create at definition.
						// Because of this. Creating menu when btn be pressed.
						btn.menu = null;
						var itemAry = [];
						
						
						itemAry.push(
							{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'LATEST_LOG'),
									icon: fn.imgUrl + 'last_log.png',
									minWidth: 200,
									handler: function(){
										
										logGrid.store.getProxy().extraParams = {
											tab: 'List'
										};
										logGrid.store.load();
										logTopCt.items.get('import').setText(_S('SYSLOG_SERVER', 'LATEST_LOG'));
										logTopCt.items.get('import').el.dom.setAttribute('data-qtip', _S('SYSLOG_SERVER', 'LATEST_LOG'));
										
									}
							},
							{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'OPEN_LOG_FROM_ARCHIVE'),
									icon: fn.imgUrl + 'archive_log.png',
									minWidth: 200,
									handler: function(){
										
										var fs = Ext.create('AS.ARC.apps.syslogServer.fileSelector', {
											isoOnly: true,
											parentWin: fn.win,
											disableMyArchive: true,
											handleOk: function (opts) {
												var phyPathDf = logTopCt.items.get('phy_path');
												phyPathDf.setValue(this.fullPhyPath);

												text = phyPathDf.getValue();
												
												var params = {
													tab: 'List',
													logfile: phyPathDf.getValue()
												}

												logGrid.store.getProxy().extraParams = params;
												logGrid.store.load();
												logTopCt.items.get('import').setText(phyPathDf.getValue().slice(8));
												logTopCt.items.get('import').el.dom.setAttribute('data-qtip', phyPathDf.getValue().slice(8));
												fn.panel.el.unmask();
											}
										});
										fs.buttonCancel.handler = function() {
											fs.win.close();
										}

										fs.win.show();
									}
							}
						);
						
						
						
						AS.ARC.ajax({
							url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'List', tab: 'Import'}),
							method: 'post',
							success: function (json, opts) {
								
								for (var i = 0; i < json.record.length; i ++) {
									
									if (json.record[i] !== '') {
										
											var text = json.record[i].slice(8);
											itemAry.push(
												{
													xtype: 'menuitem',
													text: text,
													logfile: json.record[i],
													minWidth: 200,
													width: 200,
													handler: function(item){
														
														var params = {
															tab: 'List',
															logfile: item.logfile
														}

														logGrid.store.getProxy().extraParams = params;
														logGrid.store.load();
														logTopCt.items.get('import').setText(item.text);
														logTopCt.items.get('import').el.dom.setAttribute('data-qtip', item.text);
													},
													listeners: {
														render: function(item) {
															item.el.dom.setAttribute('data-qtip', item.text);
														}
													}
												}
											);
									}
									
								}	
								
								if( !btn.menu ){
										btn.menu =  new Ext.menu.Menu({
											items: itemAry
										});
								}// end if
								btn.menu.showBy( btn, 'tl-bl' );
							},
							failure: function (json, opts) {
								if( !btn.menu ){
									btn.menu =  new Ext.menu.Menu({
										items: itemAry
									});
								}// end if
								btn.menu.showBy( btn, 'tl-bl' );
							}
						});
						
						
						
						
					}
				}
				/*{
					xtype: 'button',
					itemId: 'import',
					minWidth: 200,
					text: _S('SYSLOG_SERVER', 'IMPORT_FROM_ARCHIVE'),
					handler: function(btn) {
						
						var fs = Ext.create('AS.ARC.apps.syslogServer.fileSelector', {
							isoOnly: true,
							parentWin: fn.win,
							disableMyArchive: true,
							handleOk: function (opts) {
								var phyPathDf = logTopCt.items.get('phy_path');
								phyPathDf.setValue(this.fullPhyPath);
								
								var params = {
									tab: 'List',
									logfile: phyPathDf.getValue()
								}
								
								logGrid.store.getProxy().extraParams = params;
								logGrid.store.load();
								
								fn.panel.el.unmask();
							}
						});
						fs.buttonCancel.handler = function() {
							fs.win.close();
						}
						
						fs.win.show();
						
					}
				}*/, 
				{
					xtype: 'button',
					itemId: 'clean',
					text: _S('COMMON', 'CLEAR'),
					handler: function() {
						var confirmWin = new AS.ARC.msgWindow({
							title: _S('COMMON', 'CONFIRMATION'),
							width: 400,
							height: 160,
							parentWin: fn.win,
							iconType: 'question', // info, question, warning
							asItems: [{
								xtype: 'displayfield',
								value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
							}],
							fbar: [{
								text: _S('COMMON', 'YES'),
								handler: function () {						
									
									AS.ARC.ajax({
										url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'List', tab: 'Clean'}),
										method: 'post',
										success: function (json, opts) {
											logGrid.store.getProxy().extraParams = {
												tab: 'List'
											};
											logGrid.store.load();
										},
										failure: function (json, opts) {

										}
									});
									confirmWin.close();
								},
								scope: this
							}, 
							{
								text: _S('COMMON', 'NO'),
								handler: function () {						
									confirmWin.close();
								},
								scope: this
							}]
						});

						confirmWin.show();
										
					}
				}, 
				{
					xtype: 'tbfill'
				}, 
				{
					xtype: 'button',
					itemId: 'advance_search_btn',
					text: _S('SYSLOG_SERVER', 'ADVANCED_SEARCH'),
					handler: function() {
						
						getAdvanceSearchWin();
						
					}
				}

			]
		});
		
		var logStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'time'},
				{name: 'level'},
				{name: 'fromhostname'},
				{name: 'facility'},
				{name: 'progname'},
				{name: 'msg'}
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, {
					act: 'List'
				}),
				reader: {
					type: 'json',
					root: 'list',
					totalProperty: 'count'
				}
			},
			baseParams: {
					tab: 'List',
					msg: '',
					device: '',
					level: '',
					facility: '',
					time: '',
					start_time: '',
					end_time: '',
					progname: ''
		
			},
			listeners: {
				beforeload: function() {
					logGrid.el.mask(_S('COMMON','LOADING'));
				},
				load: function() {
					logGrid.el.unmask();
				},
				exception: function (proxy, response, operation, opts) {								
					var json = Ext.decode(response.responseText);
					AS.ARC.util.showMsgWindow({
						5000: _S('ERROR', 'SESSION_TIMEOUT'),
						5003: _S('SYSLOG_SERVER', 'SOME_PARAMETER_UNDEFINED'),
						5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE')
					}, json, fn.win);
				}
			}
		});

		var logGrid = Ext.create('Ext.grid.Panel', {
			itemId: 'grid',
			//width: 660,
			height: 400,
			cls: 'as-grid',
			border: false,
			autoScroll: true,
			store: logStore,	
			columns: [
				{
					dataIndex: 'time',
					flex: 2,
					header: _S('SYSLOG_SERVER', 'DAY_AND_TIME'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'level',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'LEVEL'),
					renderer: function(value, metadata, record) {
						
						var str;
						switch(value) {
							case 0: str = 'Emergency';
									break;
							case 1: str = 'Alert';
									break;
							case 2: str = 'Critical';
									break;
							case 3: str = 'Error';
									break;
							case 4: str = 'Warning';
									break;
							case 5: str = 'Notice';
									break;
							case 6: str = 'Info';
									break;
							case 7: str = 'Debug';
									break;
						}
						
						metadata.tdAttr = 'data-qtip="' + str + '"';
						return str;
					}

				}, 
				{
					dataIndex: 'fromhostname',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'DEVICE'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'facility',
					flex: 1,
					header: _S('SYSLOG_SERVER', 'FACILITY'),
					renderer: function(value, metadata, record) {
						
						switch(value) {
							case 0: str = 'kern';
									break;
							case 1: str = 'user';
									break;
							case 2: str = 'mail';
									break;
							case 3: str = 'daemon';
									break;
							case 4: str = 'auth';
									break;
							case 5: str = 'syslog';
									break;
							case 6: str = 'lpr';
									break;
							case 7: str = 'news';
									break;
							case 8: str = 'uucp';
									break;
							case 9: str = 'cron';
									break;
							case 10: str = 'security';
									break;
							case 11: str = 'ftp';
									break;
							case 12: str = 'ntp';
									break;
							case 13: str = 'logaudit';
									break;
							case 14: str = 'logalert';
									break;
							case 15: str = 'clock';
									break;
							case 16: str = 'local0';
									break;
							case 17: str = 'local1';
									break;
							case 18: str = 'local2';
									break;
							case 19: str = 'local3';
									break;
							case 20: str = 'local4';
									break;
							case 21: str = 'local5';
									break;
							case 22: str = 'local6';
									break;
							case 23: str = 'local7';
									break;
						}
						
						metadata.tdAttr = 'data-qtip="' + str + '"';
						return str;
					}
				}, 
				{
					dataIndex: 'progname',
					flex: 2,
					header: _S('SYSLOG_SERVER', 'PROGNAME'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'msg',
					flex: 4,
					header: _S('SYSLOG_SERVER', 'MSG'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + AS.ARC.util.replaceHtmlSymbols(value) + '"';
						
						return value;
					}
				}
			],
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border:false,
				store: logStore,
			}),
			listeners: {
				render: function() {
					
					logGrid.store.getProxy().extraParams = {
						tab: 'List'
					};
					logGrid.store.load();
				}
			}
		});

		var logTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'logTab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'LOG'),
			items: [
				//advanceSearchWin,
				logTopCt,
				logGrid
			]

		});

		var logPanel = Ext.create(Ext.tab.Panel, {
			itemId: 'logPanel',
			items: [
				logTab
			]
		});
		
		
		
		return logPanel;
	},

	getServerSettingsPanel: function () {
		var fn = this;
		var statusTip = Ext.create( 'AS.ARC.statusTip' );
		
		
		var generalContent = Ext.create(Ext.container.Container, {
			itemId: 'generalContent',
			statusTip: statusTip,
			items: [
				{
					xtype: 'fieldset',
					itemId: 'fieldset1',
					title: _S('SYSLOG_SERVER', 'TRANSMISSION'),
					layout: 'vbox',
					height: 200,
					items: [
						{
							xtype: 'checkbox',
							itemId: 'enable_server',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_SERVER'),
							handler: function(checkbox, checked) {
								if (checked) {
									generalContent.items.get('fieldset1').items.get('enable_tcp').enable();
									generalContent.items.get('fieldset1').items.get('tcp_port').enable();
									generalContent.items.get('fieldset1').items.get('enable_udp').enable();
									generalContent.items.get('fieldset1').items.get('udp_port').enable();
									generalContent.items.get('fieldset1').items.get('enable_ssl').enable();
								} else {
									generalContent.items.get('fieldset1').items.get('enable_tcp').disable();
									generalContent.items.get('fieldset1').items.get('tcp_port').disable();
									generalContent.items.get('fieldset1').items.get('enable_udp').disable();
									generalContent.items.get('fieldset1').items.get('udp_port').disable();
									generalContent.items.get('fieldset1').items.get('enable_ssl').disable();
								}
							},
							listeners: {
								afterrender: function(me) {
									if (me.checked == true) {
										generalContent.items.get('fieldset1').items.get('enable_tcp').enable();
										generalContent.items.get('fieldset1').items.get('tcp_port').enable();
										generalContent.items.get('fieldset1').items.get('enable_udp').enable();
										generalContent.items.get('fieldset1').items.get('udp_port').enable();
										generalContent.items.get('fieldset1').items.get('enable_ssl').enable();
									} else {
										generalContent.items.get('fieldset1').items.get('enable_tcp').disable();
										generalContent.items.get('fieldset1').items.get('tcp_port').disable();
										generalContent.items.get('fieldset1').items.get('enable_udp').disable();
										generalContent.items.get('fieldset1').items.get('udp_port').disable();
										generalContent.items.get('fieldset1').items.get('enable_ssl').disable();
									}
								}
							}
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enable_tcp',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_TCP'),
							style: 'margin-left: 20px',
							handler: function(checkbox, checked) {
								var enable_udp = generalContent.items.get('fieldset1').items.get('enable_udp'),
									tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port'),
									enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl'),
									udp_port = generalContent.items.get('fieldset1').items.get('udp_port'),
									apply = generalContent.items.get('apply_ct').items.get('apply');
								
								if (checked) {
									enable_udp.setValue(false);
									udp_port.disable();
									tcp_port.enable();
									enable_ssl.enable();
									
									tcp_port.clearInvalid();
									udp_port.clearInvalid();
									
									if (!tcp_port.isValid()) {
										apply.disable();
									} else {
										apply.enable();
									}
									
									
								} else {
									tcp_port.disable();
									enable_ssl.disable();
								}
							},
							listeners: {
								afterrender: function(me) {
									var enable_udp = generalContent.items.get('fieldset1').items.get('enable_udp'),
										tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port'),
										enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl'),
										udp_port = generalContent.items.get('fieldset1').items.get('udp_port'),
										apply = generalContent.items.get('apply_ct').items.get('apply');
									
									if (me.checked) {
										enable_udp.setValue(false);
										udp_port.disable();
										tcp_port.enable();
										enable_ssl.enable();
										
										tcp_port.clearInvalid();
										udp_port.clearInvalid();
										
										if (!tcp_port.isValid()) {
											apply.disable();
										} else {
											apply.enable();
										}
										
									} else {
										tcp_port.disable();
										enable_ssl.disable();
									}
								}
							}
						}, 
						{
							xtype: 'numberfield',
							itemId: 'tcp_port',
							msgTarget: AS.ARC.config.msgTarget,
							fieldLabel: _S('COMMON', 'PORT'),
							value: '514',
							style: 'margin-left: 40px',
							validator: function(value) {
								if (value < 1 || value > 65535) {
									generalContent.items.get('apply_ct').items.get('apply').disable();
									return _S('MESSAGE', 'HF00001');
								} else {
									generalContent.items.get('apply_ct').items.get('apply').enable();
									return true;
								}
							}
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enable_ssl',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_SSL'),
							style: 'margin-left: 40px'
						}, 
						{
							xtype: 'checkbox',
							itemId: 'enable_udp',
							boxLabel: _S('SYSLOG_SERVER', 'ENABLE_UDP'),
							style: 'margin-left: 20px',
							handler: function(checkbox, checked) {
								var enable_tcp = generalContent.items.get('fieldset1').items.get('enable_tcp'),
									tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port'),
									enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl'),
									udp_port = generalContent.items.get('fieldset1').items.get('udp_port'),
									apply = generalContent.items.get('apply_ct').items.get('apply');
								
								if (checked) {
									enable_tcp.setValue(false);
									tcp_port.disable();
									enable_ssl.disable();
									udp_port.enable();

									tcp_port.clearInvalid();
									udp_port.clearInvalid();
									
									
									if (!udp_port.isValid()) {
										apply.disable();
									} else {
										apply.enable();
									}
									
								} else {
									udp_port.disable();
								}
							},
							listeners: {
								afterrender: function(me) {
									var enable_tcp = generalContent.items.get('fieldset1').items.get('enable_tcp'),
										tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port'),
										enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl'),
										udp_port = generalContent.items.get('fieldset1').items.get('udp_port'),
										apply = generalContent.items.get('apply_ct').items.get('apply');
									
									if (me.checked) {
										enable_tcp.setValue(false);
										tcp_port.disable();
										enable_ssl.disable();
										udp_port.enable();
										
										tcp_port.clearInvalid();
										udp_port.clearInvalid();
										
										if (!udp_port.isValid()) {
											apply.disable();
										} else {
											apply.enable();
										}
										
										
									} else {
										udp_port.disable();
									}
								}
							}
						}, 
						{
							xtype: 'numberfield',
							itemId: 'udp_port',
							fieldLabel: _S('COMMON', 'PORT'),
							msgTarget: AS.ARC.config.msgTarget,
							value: '514',
							style: 'margin-left: 40px',
							validator: function(value) {
								if (value < 1 || value > 65535) {
									generalContent.items.get('apply_ct').items.get('apply').disable();
									return _S('MESSAGE', 'HF00001');
								} else {
									generalContent.items.get('apply_ct').items.get('apply').enable();
									return true;
								}
							}
						}

					]
				}, 
				{
					xtype: 'fieldset',
					itemId: 'fieldset2',
					title: _S('SYSLOG_SERVER', 'EXPORT'),
					layout: 'vbox',
					height: 100,
					items: [
						{
							xtype: 'displayfield',
							value: _S('SYSLOG_SERVER', 'EXPORT_HINT')
						}, 
						{
							xtype: 'button',
							text: _S('SYSLOG_SERVER', 'EXPORT'),
							handler: function () {
								var download = Ext.create('Ext.form.FormPanel', {
											items: [{ xtype: 'filefield' }]
										}),
											uform = download.getForm();

										var doSubmit = function () {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, { act: 'Setting', tab: 'Exprot_Cert'}),
												success: function (fp, o) {
												},
												failure: function (form, action) {
													var json = Ext.decode(action.response.responseText);
													AS.ARC.util.showMsgWindow({
														5000: _S('ERROR', 'SESSION_TIMEOUT')
													}, json, fn.win);

												}
											});
										}

										doSubmit();
							}
						}
					]
				},
				{
					xtype: 'container',
					itemId: 'apply_ct',
					layout: 'hbox',
					items: [
						statusTip.getTipField(),
						{
							xtype: 'tbfill'
						},
						{
							xtype: 'button',
							itemId: 'apply',
							overCls: 'x-btn-inner',
							style: 'background-image: url();',
							minWidth: 75,
							text: _S('COMMON', 'APPLY'),
							handler: function() {

								generalContent.showSetNotChange();
								

								var enable_server = generalContent.items.get('fieldset1').items.get('enable_server');
								var enable_tcp = generalContent.items.get('fieldset1').items.get('enable_tcp');
								var enable_ssl = generalContent.items.get('fieldset1').items.get('enable_ssl');
								var tcp_port = generalContent.items.get('fieldset1').items.get('tcp_port');
								var enable_udp = generalContent.items.get('fieldset1').items.get('enable_udp');
								var udp_port = generalContent.items.get('fieldset1').items.get('udp_port');

								if(enable_server.getValue() == true) {
									var enable_server_val = 1;
								} else {
									var enable_server_val = 0;
								}

								if(enable_tcp.getValue() == true) {
									var enable_tcp_val = 1;
								} else {
									var enable_tcp_val = 0;
								}

								if(enable_ssl.getValue() == true) {
									var enable_ssl_val = 1;
								} else {
									var enable_ssl_val = 0;
								}

								if(enable_udp.getValue() == true) {
									var enable_udp_val = 1;
								} else {
									var enable_udp_val = 0;
								}
								
								if (!fn.checkSettings()) {
									
									generalContent.el.mask(_S('COMMON','APPLYING'));
									AS.ARC.ajax({
										url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Set_Setting', enable_server: enable_server_val, enable_tcp: enable_tcp_val, enable_ssl: enable_ssl_val, tcp_port: tcp_port.getValue(), enable_udp: enable_udp_val, udp_port: udp_port.getValue()}),
										method: 'post',
										success: function (json, opts) {
											fn.loadData('serversettings');
											fn.loadData('archive');
											fn.loadData('notification');

											generalContent.el.unmask();
										},
										failure: function (json, opts) {
											generalContent.el.unmask();	
											AS.ARC.util.showMsgWindow({
												5000: _S('ERROR', 'SESSION_TIMEOUT'),
												5032: _S('ERROR', 'PORT_USED'),
												5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
											}, json, fn.win);
										}
									});
									generalContent.showApply();
								} else {
									generalContent.showSetNotChange();
								}
							}
						}
					
					]
				}

			]
		});
		statusTip.bindMethodWith(generalContent);
		
		var filterFacilityItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterFacilityItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'FACILITY') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'combobox',
						itemId: 'val',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value': '', 'text': ''},
								{'value': 'auth', 'text': 'auth'},
								{'value': 'authpriv', 'text': 'authpriv'},
								{'value': 'cron', 'text': 'cron'},
								{'value': 'daemon', 'text': 'daemon'},
								{'value': 'ftp', 'text': 'ftp'},
								{'value': 'kern', 'text': 'kern'},
								{'value': 'lpr', 'text': 'lpr'},
								{'value': 'mail', 'text': 'mail'},
								{'value': 'news', 'text': 'news'},
								{'value': 'security', 'text': 'security'},
								{'value': 'syslog', 'text': 'syslog'},
								{'value': 'user', 'text': 'user'},
								{'value': 'uucp', 'text': 'uucp'},
								{'value': 'local0', 'text': 'local0'},
								{'value': 'local1', 'text': 'local1'},
								{'value': 'local2', 'text': 'local2'},
								{'value': 'local3', 'text': 'local3'},
								{'value': 'local4', 'text': 'local4'},
								{'value': 'local5', 'text': 'local5'},
								{'value': 'local6', 'text': 'local6'},
								{'value': 'local7', 'text': 'local7'}
							]
						},
						editable: false,
						value: '',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}
				]
			}
		}
		
		var filterSeverityItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterSeverityItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'SEVERITY') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'higher', 'text': _S('SYSLOG_SERVER', 'HIGHER')},
								{'value': 'lower', 'text': _S('SYSLOG_SERVER', 'LOWER')},
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'higher',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'combobox',
						itemId: 'val',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value': '', 'text': ''},
								{'value': 'emerg', 'text': 'Emerg'},
								{'value': 'alert', 'text': 'Alert'},
								{'value': 'crit', 'text': 'Crit'},
								{'value': 'err', 'text': 'Err'},
								{'value': 'warning', 'text': 'Warning'},
								{'value': 'notice', 'text': 'Notice'},
								{'value': 'info', 'text': 'Info'},
								{'value': 'debug', 'text': 'Debug'}
							]
						},
						editable: false,
						value: '',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}
				]
			}
		}
		
		var filterNameItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterNameItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'FROM_HOST_NAME') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterProgramnameItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterProgramnameItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'SERVICE') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterMsgItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterMsgItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'MSG') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'contains', 'text': _S('SYSLOG_SERVER', 'CONTAINS')},
								{'value': 'notcontains', 'text': _S('SYSLOG_SERVER', 'NOTCONTAINS')}
							]
						},
						editable: false,
						value: 'contains',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var filterIpItem = function() {
			return {
				xtype: 'container',
				width: 500,
				height: 35,
				layout: 'column',
				itemId: 'filterIpItem',
				defaults: {
					margin: '0 0 0 5'
				},
				items: [
					{
						xtype: 'displayfield',
						width: 250,
						value: _S('SYSLOG_SERVER', 'IP') + ':'
					}, 
					{
						xtype: 'combobox',
						itemId: 'operator',
						width: 100,
						store: {
							fields: ['value', 'text'],
							data: [
								{'value':'equal', 'text': _S('SYSLOG_SERVER', 'EQUAL')},
								{'value': 'startwith', 'text': _S('SYSLOG_SERVER', 'STARTWITH')},
								{'value':'contains', 'text': _S('SYSLOG_SERVER', 'CONTAINS')},
								{'value': 'notequal', 'text': _S('SYSLOG_SERVER', 'NOTEQUAL')},
								{'value':'notstartwith', 'text': _S('SYSLOG_SERVER', 'NOTSTARTWITH')},
								{'value': 'notcontains', 'text': _S('SYSLOG_SERVER', 'NOTCONTAINS')}
							]
						},
						editable: false,
						value: 'equal',
						triggerAction: 'all',
						valueField: 'value',
						displayField: 'text'
					}, 
					{
						xtype: 'textfield',
						itemId: 'val',
						width: 100
					}
				]
			}
		}
		
		var getFilterAddWin = function() {
			var filterAddWin = Ext.create('AS.ARC.subWindow', {
				title: _S('COMMON', 'FILTER'),
				width: 600,
				height: 415,
				parentWin: fn.win,
				layout: 'vbox',
				onEsc: function() {
				},
				fbar: [
					{
						xtype: 'button',
						itemId: 'search',
						text: _S('COMMON', 'APPLY'),
						handler: function() {

							var str;
							var strAry = [];
							var filterFacilityVal = filterAddWin.items.get('filterItems').items.get('filterFacilityItem').items.get('val');
							var filterFacilityOp = filterAddWin.items.get('filterItems').items.get('filterFacilityItem').items.get('operator');
							var filterSeverityVal = filterAddWin.items.get('filterItems').items.get('filterSeverityItem').items.get('val');
							var filterSeverityOp = filterAddWin.items.get('filterItems').items.get('filterSeverityItem').items.get('operator');
							var filterNameVal = filterAddWin.items.get('filterItems').items.get('filterNameItem').items.get('val');
							var filterNameOp = filterAddWin.items.get('filterItems').items.get('filterNameItem').items.get('operator');
							var filterProgramnameVal = filterAddWin.items.get('filterItems').items.get('filterProgramnameItem').items.get('val');
							var filterProgramnameOp = filterAddWin.items.get('filterItems').items.get('filterProgramnameItem').items.get('operator');
							var filterMsgVal = filterAddWin.items.get('filterItems').items.get('filterMsgItem').items.get('val');
							var filterMsgOp = filterAddWin.items.get('filterItems').items.get('filterMsgItem').items.get('operator');
							var filterIpVal = filterAddWin.items.get('filterItems').items.get('filterIpItem').items.get('val');
							var filterIpOp = filterAddWin.items.get('filterItems').items.get('filterIpItem').items.get('operator');
							
							if (filterFacilityVal.getValue() != '') {
								if(filterFacilityOp.getValue() == 'equal') {
									str = '($syslogfacility-text == ' + "'" + filterFacilityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterFacilityOp.getValue() == 'notequal') {
									str = 'not ($syslogfacility-text == ' + "'" + filterFacilityVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if(filterSeverityVal.getValue() != '') {
								if(filterSeverityOp.getValue() == 'higher') {
									str = '($syslogseverity-text <= ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'lower') {
									str = 'not ($syslogseverity-text <= ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'equal') {
									str = '($syslogseverity-text == ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								} else if(filterSeverityOp.getValue() == 'notequal') {
									str = 'not ($syslogseverity-text == ' + "'" + filterSeverityVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if (filterNameVal.getValue() != '') {
								if(filterNameOp.getValue() == 'equal') {
									str = '($hostname == ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'startwith') {
									str = '($hostname startwith ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'contains') {
									str = '($hostname contains ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notequal') {
									str = 'not ($hostname == ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notstartwith') {
									str = 'not ($hostname startwith ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterNameOp.getValue() == 'notcontains') {
									str = 'not ($hostname contains ' + "'" + filterNameVal.getValue() + "')";
									strAry.push(str);
								}
							}

							if (filterProgramnameVal.getValue() != '') {
								if(filterProgramnameOp.getValue() == 'equal') {
									str = '($programname == ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'startwith') {
									str = '($programname startwith ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'contains') {
									str = '($programname contains ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notequal') {
									str = 'not ($programname == ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notstartwith') {
									str = 'not ($programname startwith ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								} else if(filterProgramnameOp.getValue() == 'notcontains') {
									str = 'not ($programname contains ' + "'" + filterProgramnameVal.getValue() + "')";
									strAry.push(str);
								}
							}


							if (filterMsgVal.getValue() != '') {
								if(filterMsgOp.getValue() == 'equal') {
									str = '($msg == ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'startwith') {
									str = '($msg startwith ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'contains') {
									str = '($msg contains ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notequal') {
									str = 'not ($msg == ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notstartwith') {
									str = 'not ($msg startwith ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								} else if(filterMsgOp.getValue() == 'notcontains') {
									str = 'not ($msg contains ' + "'" + filterMsgVal.getValue() + "')";
									strAry.push(str);
								}
							}


							if (filterIpVal.getValue() != '') {
								if(filterIpOp.getValue() == 'equal') {
									str = '($fromhost-ip == ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'startwith') {
									str = '($fromhost-ip startwith ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'contains') {
									str = '($fromhost-ip contains ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notequal') {
									str = 'not ($fromhost-ip == ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notstartwith') {
									str = 'not ($fromhost-ip startwith ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								} else if(filterIpOp.getValue() == 'notcontains') {
									str = 'not ($fromhost-ip contains ' + "'" + filterIpVal.getValue() + "')";
									strAry.push(str);
								}
							}

							var result = 'if (' + strAry.join(' and ') + ' )';


							if (strAry.length != 0) {
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'add_rule', rule: result}),
									method: 'post',
									success: function (json, opts) {
											filterGrid.store.load();
									},
									failure: function (json, opts) {
										AS.ARC.util.showMsgWindow({
											5000: _S('ERROR', 'SESSION_TIMEOUT'),
											5006: _S('SYSLOG_SERVER', 'CAN_NOT_READ_FILE'),
											5302: _S('ERROR', 'INCORRECT_PARAMETER'),
											5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
										}, json, fn.win);
									}
								});
							}
							filterAddWin.close();
						}	

					}, 
					{
						xtype: 'button',
						text: 'Cancel',
						handler: function() {
							filterAddWin.close();
						}
					}
				],
				items: [
					{
						xtype: 'panel',
						itemId: 'filterItems',
						layout: 'vbox',
						width: 600,
						height: 365,
						autoScroll: true,
						bodyStyle: 'padding: 15px',
						items: [
							filterFacilityItem(),
							filterSeverityItem(),
							filterNameItem(),
							filterProgramnameItem(),
							filterMsgItem(),
							filterIpItem()
						]
					}
				]
			});
			
			filterAddWin.show();
		};
		
		

		var filterTopCt = Ext.create(Ext.container.Container, {
			itemId: 'filterTopCt',
			layout: 'hbox',
			items: [
				{
					xtype: 'button',
					text: _S('COMMON', 'ADD'),
					handler: function() {
						getFilterAddWin();
					}
				},
				{
					xtype: 'button',
					text: _S('COMMON', 'REMOVE'),
					handler: function() {
						if(filterGrid.getSelectionModel().getCount() === 0) {
							return;
						}
						
						//var rule = filterGrid.getSelectionModel().getSelection().data.rule;
						Ext.each(filterGrid.getSelectionModel().getSelection(), function(r) {
							AS.ARC.ajax({
								url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'remove_rule', rule: r.data.rule}),
								method: 'post',
								success: function(json, opts) {
									filterGrid.store.load();
								},
								failure: function() {

								}
							});
						});
						
						
						
					}
				}
			]
		});
		
		var filterStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'rule'},
				{name: 'enable_rule'},
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, {
					act: 'Setting',
					tab: 'Filter',
					filter: 'list_rule'
				}),
				reader: {
					type: 'json',
					root: 'data',
				}
			},
			listeners: {
				beforeload: function() {
					filterGrid.el.mask(_S('COMMON','LOADING'));
				},
				load: function() {
					filterGrid.el.unmask();
				}
			}
		});
		
		var filterGrid = Ext.create(Ext.grid.GridPanel, {
			itemId: 'grid',
			height: 400,
			cls: 'as-grid',
			border: false,
			columns: [
				{
					xtype: 'checkcolumn',
					dataIndex: 'enable_rule',
					flex: 1,
					header: _S('COMMON', 'ENABLE'),
					listeners: {
						checkchange: function( comp, rowIndex, checked, eOpts ) {
							
							var models = filterGrid.getStore().getRange();
							
							if(checked) {
								
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'modify_rule_enable', rule: models[rowIndex].data.rule, enable_rule: 1}),
									method: 'post',
									success: function(json, opts) {
										filterGrid.store.load();
									},
									failure: function() {

									}
								});
							} else {
								AS.ARC.ajax({
									url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Setting', tab: 'Filter', filter: 'modify_rule_enable', rule: models[rowIndex].data.rule, enable_rule: 0}),
									method: 'post',
									success: function(json, opts) {
										filterGrid.store.load();
									},
									failure: function() {

									}
								});
							}
						}
					}
				}, 
				{
					dataIndex: 'rule',
					flex: 6,
					header: _S('SYSLOG_SERVER', 'FILTER_RULE'),
					renderer: function(value, metadata) {
						if(value == '') {
							return 'no value';
						} else {
							metadata.tdAttr = 'data-qtip="' + value + '"';
							return value;
						}
					}
				}, 
				{
					dataIndex: 'enable_rule',
					flex: 1,
					header: _S('COMMON', 'STATUS'),
					renderer: function(value) {
						if(value == 0) {
							return _S('COMMON', 'DISABLE');
						} else {
							return _S('COMMON', 'ENABLE');
						}
					}
				}
			],
			store: filterStore,
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border: false,
				store: filterStore,
			}),
			listeners: {
				render: function() {
					filterGrid.store.load();
				}
			}
		});

		var generalTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'general-tab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('COMMON', 'GENERAL'),
			items: [
				generalContent
			]

		});

		var filterTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'filter-tab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('COMMON', 'FILTER'),
			items: [
				filterTopCt,
				filterGrid
			]

		});

		var tabPanel = Ext.create(Ext.tab.Panel, {
			itemId: 'server-panel',
			items: [
				generalTab,
				filterTab
			]
		});

		return tabPanel;
	},

	getArchivePanel: function () {
		var fn = this;
		
		var statusTip = Ext.create( 'AS.ARC.statusTip' );
		
		var archivePanel = Ext.create(Ext.container.Container, {
			itemId: 'archivePanel',
			height: 400,
			//width: 700,
			statusTip: statusTip,
			//style: 'padding: 10px;',
			layout: 'vbox',
			items: [
				{
					xtype: 'fieldset',
					itemId: 'fs1',
					title: _S('SYSLOG_SERVER', 'ARCHIVE'),
					padding: '15 15 15 15',
					width: 678,
					height: 125,
					layout: 'vbox',
					items: [
						{
							xtype: 'container',
							itemId: 'container1',
							layout: 'hbox',
							height: 50,
							width: 660,
							defaults: {
								margin: 3
							},
							items: [
								{
									xtype: 'displayfield',
									width: 200,
									value: _S('SYSLOG_SERVER', 'DEFAULT_PATH')
								}, 
								{
									xtype: 'textfield',
									itemId: 'path',
									readOnly: true,
									width: 200
								}, 
								{
									xtype: 'button',
									minWidth: 100,
									text: _S('COMMON', 'BROWSE'),
									handler: function(btn) {
										var fs = Ext.create('AS.ARC.apps.syslogServer.FolderSelector', {
											parentWin: fn.win,
											pathCmp: btn.prev()
										}).show();


										fs.buttonApply.handler = function() {

											var path = fs.getValue();

											if (path && fs.pathCmp) {
												fs.pathCmp.setValue(path.substring(1));
											}

											fs.close();
											fn.panel.el.unmask();

										};

										fs.buttonCancel.handler = function() {
											fs.close();
										};


									}
								}

							]
						}, 
						{
							xtype: 'container',
							itemId: 'container2',
							layout: 'hbox',
							height: 50,
							width: 660,
							defaults: {
								margin: 3
							},
							items: [
								{
									xtype: 'displayfield',
									value: _S('SYSLOG_SERVER', 'LOG_NAME_FORMAT'),
									width: 200
								}, 
								{
									xtype: 'textfield',
									itemId: 'name',
									maxLength: 32,
									allowBlank: false,
									blankText: _S('MESSAGE', 'HF00011'),
									msgTarget: AS.ARC.config.msgTarget,
									maxLengthText: Ext.String.format(_S('MESSAGE', 'HF00016'), '32'),
									maskRe: /[^`#$%\*+=\[\]|\\:;"'<>,?\/]/,
									width: 100,
									listeners: {
										validitychange: function(tf, isValid) {
											if (isValid) {
												archivePanel.items.get('apply_ct').items.get('apply').enable();
											} else {
												archivePanel.items.get('apply_ct').items.get('apply').disable();
											}
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'format',
									width: 200,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':0, 'text':'YYYYMMDDhhmm'},
											{'value':1, 'text':'mmhhDDMMYYYY'},
										]
									},
									editable: false,
									value: 0,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'

								}
							]
						}
					
					]
					
				}, 
				{
					xtype: 'fieldset',
					itemId: 'fs2',
					width: 678,
					height: 200,
					title: _S('SYSLOG_SERVER', 'AUTO_SAVE'),
					layout: 'vbox',
					items: [
						{
							xtype: 'container',
							itemId: 'container3',
							layout: 'hbox',
							height: 50,
							width: 660,
							defaults: {
								margin: 3
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'checkbox',
									boxLabel: _S('SYSLOG_SERVER', 'LOG_SIZE_LARGER_THAN'),
									width: 200,
									handler: function(checkbox, checked) {
										var ct = checkbox.ownerCt;
										
										if(checked) {
											ct.down('[itemId=val]').enable();
											
										} else {
											ct.down('[itemId=val]').disable();
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'val',
									width: 100,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text':'100MB'},
											{'value':2, 'text':'300MB'},
											{'value':3, 'text':'500MB'},
											{'value':4, 'text':'1GB'}
										]
									},
									editable: false,
									value: 1,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
							]
						}, 
						{
							xtype: 'container',
							itemId: 'container4',
							layout: 'hbox',
							height: 50,
							width: 660,
							defaults: {
								margin: 3
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'checkbox',
									boxLabel: _S('SYSLOG_SERVER', 'LOG_COUNT_LARGER_THAN'),
									width: 200,
									handler: function(checkbox, checked) {
										var ct = checkbox.ownerCt;

										if(checked) {
											ct.down('[itemId=val]').enable();
											
										} else {
											ct.down('[itemId=val]').disable();
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'val',
									width: 100,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text':'10,000'},
											{'value':2, 'text':'30,000'},
											{'value':3, 'text':'50,000'},
											{'value':4, 'text':'100,000'},
											{'value':5, 'text':'300,000'},
											{'value':6, 'text':'500,000'},
										]
									},
									editable: false,
									value: 1,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}

							]

						}, 
						{
							xtype: 'container',
							itemId: 'container5',
							layout: 'hbox',
							height: 50,
							width: 660,
							defaults: {
								margin: 3
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'checkbox',
									boxLabel: _S('SYSLOG_SERVER', 'EARLIER_THAN'),
									width: 200,
									handler: function(checkbox, checked) {
										var ct = checkbox.ownerCt;

										if(checked) {
											ct.down('[itemId=val]').enable();
											
										} else {
											ct.down('[itemId=val]').disable();
										}
									}
								}, 
								{
									xtype: 'combobox',
									itemId: 'val',
									width: 100,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value':1, 'text': _S('SYSLOG_SERVER', 'ONE_MONTH')},
											{'value':2, 'text': _S('SYSLOG_SERVER', 'THREE_MONTH')},
											{'value':3, 'text': _S('SYSLOG_SERVER', 'SIX_MONTH')},
											{'value':4, 'text': _S('SYSLOG_SERVER', 'ONE_YEAR')}
										]
									},
									editable: false,
									value: 1,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}

							]
						}
					]
					
				
				}, 
				{
					xtype: 'container',
					itemId: 'apply_ct',
					width: 678,
					layout: 'hbox',
					items: [
						statusTip.getTipField(),
						{
							xtype: 'tbfill'
						},
						{
							xtype: 'button',
							itemId: 'apply',
							overCls: 'x-btn-inner',
							style: 'background-image: url();',
							minWidth: 75,
							text: _S('COMMON', 'APPLY'),
							handler: function() {

										
										var path = archivePanel.items.get('fs1').items.get('container1').items.get('path');
										var name = archivePanel.items.get('fs1').items.get('container2').items.get('name');
										var format = archivePanel.items.get('fs1').items.get('container2').items.get('format');
										var volume = archivePanel.items.get('fs2').items.get('container3').items.get('val');
										var count = archivePanel.items.get('fs2').items.get('container4').items.get('val');
										var period = archivePanel.items.get('fs2').items.get('container5').items.get('val');

										var volumeVal = volume.getValue();
										var countVal = count.getValue();
										var periodVal = period.getValue();

										var checkboxVolume = archivePanel.items.get('fs2').items.get('container3').items.get('checkbox');
										var checkboxCount = archivePanel.items.get('fs2').items.get('container4').items.get('checkbox');
										var checkboxPeriod = archivePanel.items.get('fs2').items.get('container5').items.get('checkbox');

										if(!checkboxVolume.checked) {
											volumeVal = 0;
										}

										if(!checkboxCount.checked) {
											countVal = 0;
										}

										if(!checkboxPeriod.checked) {
											periodVal = 0;
										}
										
								
										if (!fn.checkSettings()) {
											
											archivePanel.el.mask(_S('COMMON','APPLYING'));
											AS.ARC.ajax({
												url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Archive', tab: 'Set_Setting', archive_location: path.getValue(), archive_name: name.getValue(), archive_format: format.getValue(), archive_size: volumeVal, archive_number: countVal, archive_date: periodVal}),
												method: 'post',
												success: function (json, opts) {

														fn.loadData('serversettings');
														fn.loadData('archive');
														fn.loadData('notification');
														archivePanel.el.unmask();
												},
												failure: function (json, opts) {
													archivePanel.el.unmask();
													AS.ARC.util.showMsgWindow({
														5000: _S('ERROR', 'SESSION_TIMEOUT'),
														5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
													}, json, fn.win);
												}
											});
											archivePanel.showApply();
										} else {
											archivePanel.showSetNotChange();
										}
							}
						}
						
					]
				}
			]
		});
		
		statusTip.bindMethodWith(archivePanel);
		
		var archiveTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'archiveTab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'ARCHIVE'),
			items: [
				archivePanel
			]

		});

		var archiveTabPanel = Ext.create(Ext.tab.Panel, {
			itemId: 'archiveTabPanel',
			items: [
				archiveTab
			]
		});

		return archiveTabPanel;

	},

	getNotificationPanel: function () {
		var fn = this;
		
		var statusTip = Ext.create( 'AS.ARC.statusTip' );
		
		var noEmailNotification = Ext.create(Ext.form.field.Display, {
			itemId: 'no_email',
			width: 200,
			height: 50,
			hidden: true,
			style: 'position:absolute; left:250px; top:175px; z-index: 3000; padding: 5px; background-color: white;',
			value: Ext.String.format('No email settings please click {0}', '<a href="javascript: void(0)">HERE</a>'),
			listeners: {
				afterrender: function(me) {
									
					var link = Ext.get(me.id).down('a');
					link.on('click', function(event) {
						event.preventDefault();
						AS.ARC.core.openApp('app-settings', 'notification');
					});
				}
			}
					
		});
		
		var notificationPanel = Ext.create(Ext.container.Container, {
			itemId: 'notification',
			layout: 'vbox',
			//width: 700,
			height: 300,
			statusTip: statusTip,
			items: [
				{
					xtype: 'fieldset',
					itemId: 'fs',
					title: _S('SYSLOG_SERVER', 'SET_NOTIFICATION'),
					width: 678,
					height: 250,
					items: [
						{
							xtype: 'container',
							itemId: 'container1',
							width: 660,
							layout: 'column',
							items: [
								{
									xtype: 'checkbox',
									itemId: 'limitCheck',
									height: 25,
									width: 300,
									boxLabel: _S('SYSLOG_SERVER', 'COUNT_ONE_MINUTE'),
									handler: function(checkbox, checked) {
										
										var limitVal = notificationPanel.items.get('fs').items.get('container1').items.get('limitVal');
										var applyButton = notificationPanel.items.get('apply_ct').items.get('apply');
										if(checked) {
											limitVal.enable();
											if (limitVal.isValid()) {
												applyButton.enable();
											} else {
												applyButton.disable();
											}
										} else {
											limitVal.disable();
											applyButton.enable();
											
										}	
									}
								
								},
								{
									xtype: 'numberfield',
									msgTarget: AS.ARC.config.msgTarget,
									minValue: 1,
									maxValue: 999999999,
									value: 1,
									allowBlank: false,
									itemId: 'limitVal',
									listeners: {
										validitychange: function (me, isValid) {
											var applyButton = notificationPanel.items.get('apply_ct').items.get('apply');
											if (isValid)
												applyButton.enable();
											else
												applyButton.disable();
										}
									}
								}
							]
						},
						{
							xtype: 'container',
							itemId: 'container2',
							width: 660,
							layout: 'column',
							items: [
								{
									xtype: 'checkbox',
									itemId: 'severityCheck',
									boxLabel: _S('SYSLOG_SERVER', 'SEVERITY'),
									width: 300,
									handler: function(checkbox, checked) {
										if(checked) {
											notificationPanel.items.get('fs').items.get('container2').items.get('severityVal').enable();
										} else {
											notificationPanel.items.get('fs').items.get('container2').items.get('severityVal').disable();
										}
									}
								},
								{
									xtype: 'combobox',
									itemId: 'severityVal',
									width: 200,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value': 0, 'text': 'Emergency'},
											{'value': 1, 'text': 'Alert, Emergency'},
											{'value': 2, 'text': 'Critical, Alert, Emergency'},
											{'value': 3, 'text': 'Error, Critical, Alert, Emergency'}
										]
									},
									editable: false,
									value: 0,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
								
							]
						},
						{
							xtype: 'container',
							itemId: 'container3',
							width: 660,
							layout: 'column',
							items: [
								{
									xtype: 'checkbox',
									itemId: 'keywordCheck',
									boxLabel: _S('SYSLOG_SERVER', 'KEYWORD'),
									width: 300,
									handler: function(checkbox, checked) {
										if(checked) {
											notificationPanel.items.get('fs').items.get('container3').items.get('keyword1').enable();
											notificationPanel.items.get('fs').items.get('keyword2').enable();
											notificationPanel.items.get('fs').items.get('keyword3').enable();
										} else {
											notificationPanel.items.get('fs').items.get('container3').items.get('keyword1').disable();
											notificationPanel.items.get('fs').items.get('keyword2').disable();
											notificationPanel.items.get('fs').items.get('keyword3').disable();
										}
									}
								},
								{
									xtype: 'textfield',
									itemId: 'keyword1',
									width: 100
								}
								
							]
						},
						{
							xtype: 'textfield',
							itemId: 'keyword2',
							style: 'margin-left: 300px;',
							width: 100
						},
						{
							xtype: 'textfield',
							itemId: 'keyword3',
							style: 'margin-left: 300px;',
							width: 100
						}
					]
				}, 
				{
					xtype: 'container',
					itemId: 'apply_ct',
					layout: 'hbox',
					width: 678,
					items: [
						statusTip.getTipField(),
						{
							xtype: 'tbfill'
						},
						{
							xtype: 'button',
							itemId: 'apply',
							overCls: 'x-btn-inner',
							style: 'background-image: url();',
							minWidth: 75,
							height: 25,
							text: _S('COMMON', 'APPLY'),
							handler: function() {

								var enable_number = notificationPanel.items.get('fs').items.get('container1').items.get('limitCheck');
								var number = notificationPanel.items.get('fs').items.get('container1').items.get('limitVal').getValue();
								var enable_level = notificationPanel.items.get('fs').items.get('container2').items.get('severityCheck');
								var level = notificationPanel.items.get('fs').items.get('container2').items.get('severityVal').getValue();
								var enable_keyword = notificationPanel.items.get('fs').items.get('container3').items.get('keywordCheck');
								var keyword_count = 0;
								var keyword1 = notificationPanel.items.get('fs').items.get('container3').items.get('keyword1').getValue();
								var keyword2 = notificationPanel.items.get('fs').items.get('keyword2').getValue();
								var keyword3 = notificationPanel.items.get('fs').items.get('keyword3').getValue();

								if(enable_number.checked) {
									var enable_number_val = 1;
								} else {
									var enable_number_val = 0;
								}

								if(enable_level.checked) {
									var enable_level_val = 1;
								} else {
									var enable_level_val = 0;
								}

								if(enable_keyword.checked) {
									var enable_keyword_val = 1;
								} else {
									var enable_keyword_val = 0;
								}

								if(keyword1 != "") {
									keyword_count ++;
								}

								if(keyword2 != "") {
									keyword_count ++;
								}

								if(keyword3 != "") {
									keyword_count ++;
								}
								
								
								if (!fn.checkSettings()) {
									notificationPanel.el.mask(_S('COMMON','APPLYING'));
									AS.ARC.ajax({
											url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Notifacation', tab: 'Set_Setting', enable_number: enable_number_val, number: number, enable_level: enable_level_val, level: level, enable_keyword: enable_keyword_val, keyword_count: keyword_count, keyword1: keyword1, keyword2: keyword2, keyword3: keyword3}),
											method: 'post',
											success: function (json, opts) {
												fn.loadData('serversettings');
												fn.loadData('archive');
												fn.loadData('notification');
												notificationPanel.el.unmask();
											},
											failure: function (json, opts) {
												notificationPanel.el.unmask();
												AS.ARC.util.showMsgWindow({
													5000: _S('ERROR', 'SESSION_TIMEOUT'),
													5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
												}, json, fn.win);
											}
										});
										notificationPanel.showApply();
								} else {
									notificationPanel.showSetNotChange();
								}
							}
						}
					]
				}
				
			]
		});
		
		statusTip.bindMethodWith(notificationPanel);
		
		var notificationTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'notificationTab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'NOTIFICATION'),
			items: [
				noEmailNotification,
				notificationPanel
			]

		});

		var notificationTabPanel = Ext.create(Ext.tab.Panel, {
			itemId: 'notificationTabPanel',
			items: [
				notificationTab
			]
		});

		return notificationTabPanel;
		
	},

	getHistoryPanel: function () {
			var fn = this;
		
			var historyTopCt = Ext.create(Ext.container.Container, {
			itemId: 'history-topct',
			layout: 'hbox',
			items: [
				{
					xtype: 'splitbutton',
					itemId: 'export',
					text: _S('SYSLOG_SERVER', 'EXPORT'),
					minWidth: 100,
					onClick: function () {
						var btn = this;

						// Menu would show at wrong position. If create at definition.
						// Because of this. Creating menu when btn be pressed.
						if( !btn.menu ){
							btn.menu =  new Ext.menu.Menu({
								items: [{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'HTML'),
									icon: fn.imgUrl + 'html-icon.png',
									handler: function(){
										
										var download = Ext.create('Ext.form.FormPanel', {
											items: [{ xtype: 'filefield' }]
										}),
											uform = download.getForm();

										var doSubmit = function () {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, { act: 'History', tab: 'Export_History', format: 'html'}),
												success: function (fp, o) {
												},
												failure: function (form, action) {
													var json = Ext.decode(action.response.responseText);
													AS.ARC.util.showMsgWindow({
														5005: _S('SYSLOG_SERVER', 'LOG_NO_DATA')
													}, json, fn.win);

												}
											});
										}

										doSubmit();		
									}
								},
								{
									xtype: 'menuitem',
									text: _S('SYSLOG_SERVER', 'CSV'),
									icon: fn.imgUrl + 'csv-icon.png',
									handler: function(){
										var download = Ext.create('Ext.form.FormPanel', {
											items: [{ xtype: 'filefield' }]
										}),
											uform = download.getForm();

										var doSubmit = function () {
											uform.submit({
												url: AS.ARC.util.getApiUrlWithSid(fn.apiUrl, { act: 'History', tab: 'Export_History', format: 'csv'}),
												success: function (fp, o) {
												},
												failure: function (form, action) {
													var json = Ext.decode(action.response.responseText);
													AS.ARC.util.showMsgWindow({
														5005: _S('SYSLOG_SERVER', 'LOG_NO_DATA')
													}, json, fn.win);

												}
											});
										}

										doSubmit();
									}
								}]
							});
						}// end if
						btn.menu.showBy( btn, 'tl-bl' );
					}
				},
				{
					xtype: 'button',
					itemId: 'clean',
					minWidth: 100,
					text: _S('COMMON', 'CLEAR'),
					handler: function() {
						var confirmWin = new AS.ARC.msgWindow({
							title: _S('COMMON', 'CONFIRMATION'),
							width: 400,
							height: 160,
							parentWin: fn.win,
							iconType: 'question', // info, question, warning
							asItems: [{
								xtype: 'displayfield',
								value: _S('SYSTEMINFORMATION', 'NOTE_REMOVE_LOG')
							}],
							fbar: [
							{
								text: _S('COMMON', 'YES'),
								handler: function () {						
									
									AS.ARC.ajax({
										url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'History', tab: 'Clean'}),
										method: 'post',
										success: function (json, opts) {
											historyGrid.store.load();
										},
										failure: function (json, opts) {

										}
									});
									confirmWin.close();
								},
								scope: this
							}, 
							{
								text: _S('COMMON', 'NO'),
								handler: function () {						
									confirmWin.close();
								},
								scope: this
							}]
						});

						confirmWin.show();
					}
				}

			]
		});
		
		var historyStore = Ext.create('Ext.data.JsonStore', {
			autoDestroy: true,
			fields: [
				{name: 'date'},
				{name: 'time'},
				{name: 'msg'}
			],
			proxy: {
				type: 'ajax',
				url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {
					act: 'History',
					tab: 'List'
				}),
				reader: {
					type: 'json',
					root: 'list',
					totalProperty: 'count'
				}
			},
			listeners: {
				beforeload: function() {
					historyGrid.el.mask(_S('COMMON','LOADING'));
				},
				load: function() {
					historyGrid.el.unmask();
				}
			}
		});
		
		var historyGrid = Ext.create(Ext.grid.GridPanel, {
			itemId: 'grid',
			//width: 660,
			height: 400,
			cls: 'as-grid',
			border: false,
			store: historyStore,
			columns: [
				{
					dataIndex: 'date',
					flex: 2,
					header: _S('COMMON', 'DATE'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'time',
					flex: 2,
					header: _S('COMMON', 'TIME'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}, 
				{
					dataIndex: 'msg',
					flex: 5,
					header: _S('HARDWARE', 'TEXT_MESSAGE'),
					renderer: function (value, metadata, record) {
						metadata.tdAttr = 'data-qtip="' + value + '"';
						
						return value;
					}
				}
			],
			bbar: Ext.create('AS.ARC.pagingToolbar', {
				border: false,
				store: historyStore,
			}),
			listeners: {
				render: function() {
					historyGrid.store.load();
				}
			}
		});


		var historyPanel = Ext.create(Ext.container.Container, {
			itemId: 'historyPanel',
			items: [
				historyTopCt,
				historyGrid
			]
		});
		
		
		var historyTab = Ext.create(AS.ARC.fnFormPanel, {
			itemId: 'historyTab',
			page: fn,
			cls: 'as-page-panel',
			title: _S('SYSLOG_SERVER', 'HISTORY'),
			items: [
				historyPanel
			]

		});

		var historyTabPanel = Ext.create(Ext.tab.Panel, {
			itemId: 'historyTabPanel',
			items: [
				historyTab
			]
		});

		return historyTabPanel;
		
		
	}

});


/**
 * @class AS.ARC.apps.syslogServer.main
 * @extends AS.ARC._appBase
 *<p>Main app</p>
 */

Ext.define('AS.ARC.apps.syslogServer.main', {
	extend: 'AS.ARC._appBase',

	appTag: 'syslogServer',
	title: 'Syslog Server',
	appMaxNum: 1,
	appOpenNum: 0,
	appIsReady: true,
	appWins: [],

	createWindow: function () {
		
		
		var desktop = this.core.getDesktop(),
			app = this;
		if ((this.appOpenNum === this.appMaxNum) || !this.appIsReady) {
			this.appWins[0].show();
			return;
		}

		// Set appIsReady to false
		this.appIsReady = false;

		var newsyslogServer = new AS.ARC.apps.syslogServer.core({
			app: this,
			desktop: desktop,
			id: this.id + '-' + Ext.id()
		});

		newsyslogServer.win.on('beforeclose', function () {
			app.appOpenNum--;
			app.appIsReady = true;
			app.appWins.pop();
			clearInterval(newsyslogServer.statisticsChartId);
			clearInterval(newsyslogServer.notificationId);
		});
		newsyslogServer.win.show();

		// Get all wins for handling
		this.appWins.push(newsyslogServer.win);
	}

});